@@ -70,18 +70,11 @@ col_setup(column_info *cinfo, const gint num_cols)
     G_REGEX_ANCHORED, G_REGEX_MATCH_ANCHORED, NULL);
 }
 
-static void
-col_custom_ids_free_wrapper(gpointer data, gpointer user_data _U_)
-{
-  g_free(data);
-}
-
 static void
 col_custom_fields_ids_free(GSList** custom_fields_id)
 {
   if (*custom_fields_id != NULL) {
-    g_slist_foreach(*custom_fields_id, col_custom_ids_free_wrapper, NULL);
-    g_slist_free(*custom_fields_id);
+    g_slist_free_full(*custom_fields_id, g_free);
   }
   *custom_fields_id = NULL;
 }
@@ -315,7 +308,7 @@ col_clear(column_info *cinfo, const gint el)
   }
 
 #define COL_CHECK_REF_TIME(fd, buf)         \
-  if (fd->flags.ref_time) {                 \
+  if (fd->ref_time) {                 \
     g_strlcpy(buf, "*REF*", COL_MAX_LEN );  \
     return;                                 \
   }
@@ -416,7 +409,7 @@ col_append_lstr(column_info *cinfo, const gint el, const gchar *str1, ...)
       va_start(ap, str1);
       str = str1;
       do {
-         if G_UNLIKELY(str == NULL)
+         if (G_UNLIKELY(str == NULL))
              str = "(null)";
 
          pos += g_strlcpy(&col_item->col_buf[pos], str, max_len - pos);
@@ -463,7 +456,7 @@ void
 col_append_frame_number(packet_info *pinfo, const gint col, const gchar *fmt_str, guint frame_num)
 {
   col_append_fstr(pinfo->cinfo, col, fmt_str, frame_num);
-  if (!pinfo->fd->flags.visited) {
+  if (!pinfo->fd->visited) {
     col_data_changed_ = TRUE;
   }
 }
@@ -754,7 +747,7 @@ col_add_lstr(column_info *cinfo, const gint el, const gchar *str1, ...)
       va_start(ap, str1);
       str = str1;
       do {
-         if G_UNLIKELY(str == NULL)
+         if (G_UNLIKELY(str == NULL))
              str = "(null)";
 
          pos += g_strlcpy(&col_item->col_buf[pos], str, max_len - pos);
@@ -886,7 +879,7 @@ set_abs_ymd_time(const frame_data *fd, gchar *buf, char *decimal_point, gboolean
   time_t then;
   int tsprecision;
 
-  if (fd->flags.has_ts) {
+  if (fd->has_ts) {
     then = fd->abs_ts.secs;
     if (local)
       tmp = localtime(&then);
@@ -1020,7 +1013,7 @@ set_abs_ydoy_time(const frame_data *fd, gchar *buf, char *decimal_point, gboolea
   time_t then;
   int tsprecision;
 
-  if (fd->flags.has_ts) {
+  if (fd->has_ts) {
     then = fd->abs_ts.secs;
     if (local)
       tmp = localtime(&then);
@@ -1392,7 +1385,7 @@ col_set_rel_time(const frame_data *fd, column_info *cinfo, const int col)
 {
   nstime_t del_rel_ts;
 
-  if (!fd->flags.has_ts) {
+  if (!fd->has_ts) {
     cinfo->columns[col].col_buf[0] = '\0';
     return;
   }
@@ -1446,7 +1439,7 @@ col_set_delta_time_dis(const frame_data *fd, column_info *cinfo, const int col)
 {
   nstime_t del_dis_ts;
 
-  if (!fd->flags.has_ts) {
+  if (!fd->has_ts) {
     cinfo->columns[col].col_buf[0] = '\0';
     return;
   }
@@ -1478,7 +1471,7 @@ set_abs_time(const frame_data *fd, gchar *buf, char *decimal_point, gboolean loc
   time_t then;
   int tsprecision;
 
-  if (fd->flags.has_ts) {
+  if (fd->has_ts) {
     then = fd->abs_ts.secs;
     if (local)
       tmp = localtime(&then);
@@ -1593,7 +1586,7 @@ set_epoch_time(const frame_data *fd, gchar *buf)
 {
   int tsprecision;
 
-  if (!fd->flags.has_ts) {
+  if (!fd->has_ts) {
     buf[0] = '\0';
     return FALSE;
   }
@@ -1681,7 +1674,7 @@ set_fd_time(const epan_t *epan, frame_data *fd, gchar *buf)
     break;
 
   case TS_RELATIVE:
-    if (fd->flags.has_ts) {
+    if (fd->has_ts) {
       nstime_t del_rel_ts;
 
       frame_delta_abs_time(epan, fd, fd->frame_ref_num, &del_rel_ts);
@@ -1702,7 +1695,7 @@ set_fd_time(const epan_t *epan, frame_data *fd, gchar *buf)
     break;
 
   case TS_DELTA:
-    if (fd->flags.has_ts) {
+    if (fd->has_ts) {
       nstime_t del_cap_ts;
 
       frame_delta_abs_time(epan, fd, fd->num - 1, &del_cap_ts);
@@ -1723,7 +1716,7 @@ set_fd_time(const epan_t *epan, frame_data *fd, gchar *buf)
     break;
 
   case TS_DELTA_DIS:
-    if (fd->flags.has_ts) {
+    if (fd->has_ts) {
       nstime_t del_dis_ts;
 
       frame_delta_abs_time(epan, fd, fd->prev_dis_num, &del_dis_ts);
@@ -1890,7 +1883,7 @@ col_set_time(column_info *cinfo, const gint el, const nstime_t *ts, const char *
   if (!CHECK_COL(cinfo, el))
     return;
 
-  /** @todo TODO: We don't respect fd->flags.ref_time (no way to access 'fd')
+  /** @todo TODO: We don't respect fd->ref_time (no way to access 'fd')
   COL_CHECK_REF_TIME(fd, buf);
   */
 
