@@ -1208,7 +1208,7 @@ dissect_snmp_engineid(proto_tree *tree, packet_info *pinfo, tvbuff_t *tvb, int o
 					if (len_remain==8) {
 						seconds = (time_t)tvb_get_letohl(tvb, offset + 4);
 					} else {
-						seconds = (time_t)tvb_get_letoh64(tvb, offset + 4);
+						seconds = (time_t)tvb_get_letohi64(tvb, offset + 4);
 					}
 					ts.secs = seconds;
 					ts.nsecs = 0;
