@@ -9,19 +9,7 @@
  * By Gerald Combs <gerald@wireshark.org>
  * Copyright 1998 Gerald Combs
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 /* This code is based on the following documents;
@@ -41,6 +29,7 @@
 #include <epan/packet.h>
 #include <epan/etypes.h>
 #include <epan/addr_resolv.h>
+#include "packet-mpls.h"
 
 /** Value declarations for CFM EOAM (IEEE 802.1ag) dissection */
 #define IEEE8021 0x00
@@ -2266,7 +2255,7 @@ void proto_register_cfm(void)
 void proto_reg_handoff_cfm(void)
 {
 	dissector_add_uint("ethertype", ETHERTYPE_CFM, cfm_handle);
-	dissector_add_for_decode_as("pwach.channel_type", cfm_handle);
+	dissector_add_uint("pwach.channel_type", PW_ACH_TYPE_MPLSTP_OAM, cfm_handle);
 }
 
 /*
