@@ -1202,7 +1202,7 @@ void proto_register_dplay(void)
         { "short player message", "dplay.flags.short_player_msg", FT_BOOLEAN, 32,
         TFS(&tfs_dplay_flag), DPLAY_FLAG_SHORT_PLAYER_MSG, "Short Player Msg", HFILL}},
     { &hf_dplay_flags_ignored,
-        { "ignored", "dplay.flags.ignored", FT_BOOLEAN, 32,
+        { "ignored", "dplay.ignored", FT_BOOLEAN, 32,
         TFS(&tfs_dplay_flag), DPLAY_FLAG_IGNORED, NULL, HFILL}},
     { &hf_dplay_flags_can_join,
         { "can join", "dplay.flags.can_join", FT_BOOLEAN, 32,
