@@ -113,36 +113,19 @@ static const value_string p2p_dirs[] = {
 	{ 0, NULL }
 };
 
-#define PACKET_WORD_DIRECTION_MASK                        0x00000003
-#define PACKET_WORD_RECEPTION_TYPE_MASK                   0x0000001C
-#define PACKET_WORD_FCS_LENGTH_MASK                       0x000001E0
-#define PACKET_WORD_RESERVED_MASK                         0x0000FE00
-#define PACKET_WORD_CRC_ERR_MASK                          0x01000000
-#define PACKET_WORD_PACKET_TOO_LONG_ERR_MASK              0x02000000
-#define PACKET_WORD_PACKET_TOO_SHORT_ERR_MASK             0x04000000
-#define PACKET_WORD_WRONG_INTER_FRAME_GAP_ERR_MASK        0x08000000
-#define PACKET_WORD_UNALIGNED_FRAME_ERR_MASK              0x10000000
-#define PACKET_WORD_START_FRAME_DELIMITER_ERR_MASK        0x20000000
-#define PACKET_WORD_PREAMBLE_ERR_MASK                     0x40000000
-#define PACKET_WORD_SYMBOL_ERR_MASK                       0x80000000
-
 static const value_string packet_word_directions[] = {
-	{ 0x00, "Not available" },
-	{ 0x01, "Inbound" },
-	{ 0x02, "Outbound" },
-	{ 0x03, "Undefined" },
+	{ PACK_FLAGS_DIRECTION_UNKNOWN,  "Unknown" },
+	{ PACK_FLAGS_DIRECTION_INBOUND,  "Inbound" },
+	{ PACK_FLAGS_DIRECTION_OUTBOUND, "Outbound" },
 	{ 0, NULL }
 };
 
 static const value_string packet_word_reception_types[] = {
-	{ 0x00, "Not specified" },
-	{ 0x01, "Unicast" },
-	{ 0x02, "Multicast" },
-	{ 0x03, "Broadcast" },
-	{ 0x04, "Promiscuous" },
-	{ 0x05, "Undefined" },
-	{ 0x06, "Undefined" },
-	{ 0x07, "Undefined" },
+	{ PACK_FLAGS_RECEPTION_TYPE_UNSPECIFIED, "Not specified" },
+	{ PACK_FLAGS_RECEPTION_TYPE_UNICAST,     "Unicast" },
+	{ PACK_FLAGS_RECEPTION_TYPE_MULTICAST,   "Multicast" },
+	{ PACK_FLAGS_RECEPTION_TYPE_BROADCAST,   "Broadcast" },
+	{ PACK_FLAGS_RECEPTION_TYPE_PROMISCUOUS, "Promiscuous" },
 	{ 0, NULL }
 };
 
@@ -167,14 +150,14 @@ ensure_tree_item(proto_tree *tree, gint count)
 /****************************************************************************/
 /* whenever a frame packet is seen by the tap listener */
 /* Add a new frame into the graph */
-static gboolean
+static tap_packet_status
 frame_seq_analysis_packet( void *ptr, packet_info *pinfo, epan_dissect_t *edt _U_, const void *dummy _U_)
 {
 	seq_analysis_info_t *sainfo = (seq_analysis_info_t *) ptr;
 	seq_analysis_item_t *sai = sequence_analysis_create_sai_with_addresses(pinfo, sainfo);
 
 	if (!sai)
-		return FALSE;
+		return TAP_PACKET_DONT_REDRAW;
 
 	sai->frame_number = pinfo->num;
 
@@ -191,7 +174,7 @@ frame_seq_analysis_packet( void *ptr, packet_info *pinfo, epan_dissect_t *edt _U
 
 	g_queue_push_tail(sainfo->items, sai);
 
-	return TRUE;
+	return TAP_PACKET_REDRAW;
 }
 
 /*
@@ -208,7 +191,7 @@ register_frame_end_routine(packet_info *pinfo, void (*func)(void))
 typedef void (*void_func_t)(void);
 
 static void
-call_frame_end_routine(gpointer routine, gpointer dummy _U_)
+call_frame_end_routine(gpointer routine)
 {
 	void_func_t func = (void_func_t)routine;
 	(*func)();
@@ -237,10 +220,21 @@ dissect_frame(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree, void*
 	case REC_TYPE_PACKET:
 		pinfo->current_proto = "Frame";
 		if (pinfo->rec->presence_flags & WTAP_HAS_PACK_FLAGS) {
-			if (pinfo->rec->rec_header.packet_header.pack_flags & 0x00000001)
+			switch (PACK_FLAGS_DIRECTION(pinfo->rec->rec_header.packet_header.pack_flags)) {
+
+			case PACK_FLAGS_DIRECTION_UNKNOWN:
+			default:
+				pinfo->p2p_dir = P2P_DIR_UNKNOWN;
+				break;
+
+			case PACK_FLAGS_DIRECTION_INBOUND:
 				pinfo->p2p_dir = P2P_DIR_RECV;
-			if (pinfo->rec->rec_header.packet_header.pack_flags & 0x00000002)
+				break;
+
+			case PACK_FLAGS_DIRECTION_OUTBOUND:
 				pinfo->p2p_dir = P2P_DIR_SENT;
+				break;
+			}
 		}
 
 		/*
@@ -261,13 +255,14 @@ dissect_frame(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree, void*
 				break;
 
 			case WTAP_ENCAP_BLUETOOTH_HCI:
-				pinfo->p2p_dir = pinfo->pseudo_header->bthci.sent;
+				pinfo->p2p_dir = pinfo->pseudo_header->bthci.sent ?
+					P2P_DIR_SENT : P2P_DIR_RECV;
 				break;
 
 			case WTAP_ENCAP_LAPB:
 			case WTAP_ENCAP_FRELAY_WITH_PHDR:
 				pinfo->p2p_dir =
-				    (pinfo->pseudo_header->x25.flags & FROM_DCE) ?
+				    (pinfo->pseudo_header->dte_dce.flags & FROM_DCE) ?
 				    P2P_DIR_RECV : P2P_DIR_SENT;
 				break;
 
@@ -320,10 +315,10 @@ dissect_frame(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree, void*
 		item = proto_tree_add_item(tree, proto_pkt_comment, tvb, 0, 0, ENC_NA);
 		comments_tree = proto_item_add_subtree(item, ett_comments);
 		comment_item = proto_tree_add_string_format(comments_tree, hf_comments_text, tvb, 0, 0,
-							                   fr_data->pkt_comment, "%s",
-							                   fr_data->pkt_comment);
+									   fr_data->pkt_comment, "%s",
+									   fr_data->pkt_comment);
 		expert_add_info_format(pinfo, comment_item, &ei_comments_text,
-					                       "%s",  fr_data->pkt_comment);
+							       "%s",  fr_data->pkt_comment);
 
 
 	}
@@ -362,10 +357,19 @@ dissect_frame(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree, void*
 				    pinfo->rec->rec_header.packet_header.interface_id);
 			}
 			if (pinfo->rec->presence_flags & WTAP_HAS_PACK_FLAGS) {
-				if (pinfo->rec->rec_header.packet_header.pack_flags & 0x00000001)
+				switch (PACK_FLAGS_DIRECTION(pinfo->rec->rec_header.packet_header.pack_flags)) {
+
+				case PACK_FLAGS_DIRECTION_INBOUND:
 					proto_item_append_text(ti, " (inbound)");
-				if (pinfo->rec->rec_header.packet_header.pack_flags & 0x00000002)
+					break;
+
+				case PACK_FLAGS_DIRECTION_OUTBOUND:
 					proto_item_append_text(ti, " (outbound)");
+					break;
+
+				default:
+					break;
+				}
 			}
 			break;
 
@@ -430,10 +434,10 @@ dissect_frame(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree, void*
 				if_item = proto_tree_add_uint(fh_tree, hf_frame_interface_id, tvb, 0, 0, pinfo->rec->rec_header.packet_header.interface_id);
 			}
 
-                        if (interface_description) {
+			if (interface_description) {
 				if_tree = proto_item_add_subtree(if_item, ett_ifname);
 				proto_tree_add_string(if_tree, hf_frame_interface_description, tvb, 0, 0, interface_description);
-                        }
+			}
 		}
 
 		if (pinfo->rec->presence_flags & WTAP_HAS_PACK_FLAGS) {
@@ -505,7 +509,7 @@ dissect_frame(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree, void*
 						   0, 0, &(pinfo->rel_ts));
 			PROTO_ITEM_SET_GENERATED(item);
 
-			if (pinfo->fd->flags.ref_time) {
+			if (pinfo->fd->ref_time) {
 				ti = proto_tree_add_item(fh_tree, hf_frame_time_reference, tvb, 0, 0, ENC_NA);
 				PROTO_ITEM_SET_GENERATED(ti);
 			}
@@ -535,10 +539,10 @@ dissect_frame(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree, void*
 			PROTO_ITEM_SET_GENERATED(ti);
 		}
 
-		ti = proto_tree_add_boolean(fh_tree, hf_frame_marked, tvb, 0, 0,pinfo->fd->flags.marked);
+		ti = proto_tree_add_boolean(fh_tree, hf_frame_marked, tvb, 0, 0,pinfo->fd->marked);
 		PROTO_ITEM_SET_GENERATED(ti);
 
-		ti = proto_tree_add_boolean(fh_tree, hf_frame_ignored, tvb, 0, 0,pinfo->fd->flags.ignored);
+		ti = proto_tree_add_boolean(fh_tree, hf_frame_ignored, tvb, 0, 0,pinfo->fd->ignored);
 		PROTO_ITEM_SET_GENERATED(ti);
 
 		if (pinfo->rec->rec_type == REC_TYPE_PACKET) {
@@ -564,7 +568,7 @@ dissect_frame(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree, void*
 		}
 	}
 
-	if (pinfo->fd->flags.ignored) {
+	if (pinfo->fd->ignored) {
 		/* Ignored package, stop handling here */
 		col_set_str(pinfo->cinfo, COL_INFO, "<Ignored>");
 		proto_tree_add_boolean_format(tree, hf_frame_ignored, tvb, 0, 0, TRUE, "This frame is marked as ignored");
@@ -640,7 +644,7 @@ dissect_frame(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree, void*
 					if (!dissector_try_uint(wtap_fts_rec_dissector_table, file_type_subtype,
 					    tvb, pinfo, parent_tree)) {
 						col_set_str(pinfo->cinfo, COL_PROTOCOL, "UNKNOWN");
-						col_add_fstr(pinfo->cinfo, COL_INFO, "WTAP_ENCAP = %d",
+						col_add_fstr(pinfo->cinfo, COL_INFO, "WTAP FT ST = %d",
 							     file_type_subtype);
 						call_data_dissector(tvb, pinfo, parent_tree);
 					}
@@ -758,10 +762,10 @@ dissect_frame(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree, void*
 	}
 
 	/* Attempt to (re-)calculate color filters (if any). */
-	if (pinfo->fd->flags.need_colorize) {
+	if (pinfo->fd->need_colorize) {
 		color_filter = color_filters_colorize_packet(fr_data->color_edt);
 		pinfo->fd->color_filter = color_filter;
-		pinfo->fd->flags.need_colorize = 0;
+		pinfo->fd->need_colorize = 0;
 	} else {
 		color_filter = pinfo->fd->color_filter;
 	}
@@ -780,8 +784,7 @@ dissect_frame(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree, void*
 
 
 	if (pinfo->frame_end_routines) {
-		g_slist_foreach(pinfo->frame_end_routines, &call_frame_end_routine, NULL);
-		g_slist_free(pinfo->frame_end_routines);
+		g_slist_free_full(pinfo->frame_end_routines, &call_frame_end_routine);
 		pinfo->frame_end_routines = NULL;
 	}
 
@@ -812,7 +815,7 @@ dissect_frame(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree, void*
 				}
 			}
 		}
-        }
+	}
 
 	return tvb_captured_length(tvb);
 }
@@ -938,62 +941,62 @@ proto_register_frame(void)
 
 		{ &hf_frame_pack_direction,
 		  { "Direction", "frame.packet_flags_direction",
-		    FT_UINT32, BASE_HEX, VALS(packet_word_directions), PACKET_WORD_DIRECTION_MASK,
+		    FT_UINT32, BASE_HEX, VALS(packet_word_directions), PACK_FLAGS_DIRECTION_MASK,
 		    NULL, HFILL }},
 
 		{ &hf_frame_pack_reception_type,
 		  { "Reception type", "frame.packet_flags_reception_type",
-		    FT_UINT32, BASE_DEC, VALS(packet_word_reception_types), PACKET_WORD_RECEPTION_TYPE_MASK,
+		    FT_UINT32, BASE_DEC, VALS(packet_word_reception_types), PACK_FLAGS_RECEPTION_TYPE_MASK,
 		    NULL, HFILL }},
 
 		{ &hf_frame_pack_fcs_length,
 		  { "FCS length", "frame.packet_flags_fcs_length",
-		    FT_UINT32, BASE_DEC, NULL, PACKET_WORD_FCS_LENGTH_MASK,
+		    FT_UINT32, BASE_DEC, NULL, PACK_FLAGS_FCS_LENGTH_MASK,
 		    NULL, HFILL }},
 
 		{ &hf_frame_pack_reserved,
 		  { "Reserved", "frame.packet_flags_reserved",
-		    FT_UINT32, BASE_DEC, NULL, PACKET_WORD_RESERVED_MASK,
+		    FT_UINT32, BASE_DEC, NULL, PACK_FLAGS_RESERVED_MASK,
 		    NULL, HFILL }},
 
 		{ &hf_frame_pack_crc_error,
 		  { "CRC error", "frame.packet_flags_crc_error",
-		    FT_BOOLEAN, 32, TFS(&tfs_set_notset), PACKET_WORD_CRC_ERR_MASK,
+		    FT_BOOLEAN, 32, TFS(&tfs_set_notset), PACK_FLAGS_CRC_ERROR,
 		    NULL, HFILL }},
 
 		{ &hf_frame_pack_wrong_packet_too_long_error,
 		  { "Packet too long error", "frame.packet_flags_packet_too_error",
-		    FT_BOOLEAN, 32, TFS(&tfs_set_notset), PACKET_WORD_PACKET_TOO_LONG_ERR_MASK,
+		    FT_BOOLEAN, 32, TFS(&tfs_set_notset), PACK_FLAGS_PACKET_TOO_LONG,
 		    NULL, HFILL }},
 
 		{ &hf_frame_pack_wrong_packet_too_short_error,
 		  { "Packet too short error", "frame.packet_flags_packet_too_short_error",
-		    FT_BOOLEAN, 32, TFS(&tfs_set_notset), PACKET_WORD_PACKET_TOO_SHORT_ERR_MASK,
+		    FT_BOOLEAN, 32, TFS(&tfs_set_notset), PACK_FLAGS_PACKET_TOO_SHORT,
 		    NULL, HFILL }},
 
 		{ &hf_frame_pack_wrong_inter_frame_gap_error,
 		  { "Wrong interframe gap error", "frame.packet_flags_wrong_inter_frame_gap_error",
-		    FT_BOOLEAN, 32, TFS(&tfs_set_notset), PACKET_WORD_WRONG_INTER_FRAME_GAP_ERR_MASK,
+		    FT_BOOLEAN, 32, TFS(&tfs_set_notset), PACK_FLAGS_WRONG_INTER_FRAME_GAP,
 		    NULL, HFILL }},
 
 		{ &hf_frame_pack_unaligned_frame_error,
 		  { "Unaligned frame error", "frame.packet_flags_unaligned_frame_error",
-		    FT_BOOLEAN, 32, TFS(&tfs_set_notset), PACKET_WORD_UNALIGNED_FRAME_ERR_MASK,
+		    FT_BOOLEAN, 32, TFS(&tfs_set_notset), PACK_FLAGS_UNALIGNED_FRAME,
 		    NULL, HFILL }},
 
 		{ &hf_frame_pack_start_frame_delimiter_error,
 		  { "Start frame delimiter error", "frame.packet_flags_start_frame_delimiter_error",
-		    FT_BOOLEAN, 32, TFS(&tfs_set_notset), PACKET_WORD_START_FRAME_DELIMITER_ERR_MASK,
+		    FT_BOOLEAN, 32, TFS(&tfs_set_notset), PACK_FLAGS_START_FRAME_DELIMITER_ERROR,
 		    NULL, HFILL }},
 
 		{ &hf_frame_pack_preamble_error,
 		  { "Preamble error", "frame.packet_flags_preamble_error",
-		    FT_BOOLEAN, 32, TFS(&tfs_set_notset), PACKET_WORD_PREAMBLE_ERR_MASK,
+		    FT_BOOLEAN, 32, TFS(&tfs_set_notset), PACK_FLAGS_PREAMBLE_ERROR,
 		    NULL, HFILL }},
 
 		{ &hf_frame_pack_symbol_error,
 		  { "Symbol error", "frame.packet_flags_symbol_error",
-		    FT_BOOLEAN, 32, TFS(&tfs_set_notset), PACKET_WORD_SYMBOL_ERR_MASK,
+		    FT_BOOLEAN, 32, TFS(&tfs_set_notset), PACK_FLAGS_SYMBOL_ERROR,
 		    NULL, HFILL }},
 
 		{ &hf_comments_text,
@@ -1033,7 +1036,7 @@ proto_register_frame(void)
 
 		for (i = 0; i < encap_count; i++) {
 			arr[i].value = i;
-			arr[i].strptr = wtap_encap_string(i);
+			arr[i].strptr = wtap_encap_description(i);
 		}
 		arr[encap_count].value = 0;
 		arr[encap_count].strptr = NULL;
