@@ -9,19 +9,7 @@
  *
  * Copied from packet-pop.c
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "config.h"
@@ -62,9 +50,11 @@ static int hf_ftp_epsv_ip = -1;
 static int hf_ftp_epsv_ipv6 = -1;
 static int hf_ftp_epsv_port = -1;
 static int hf_ftp_command_response_frames = -1;
+static int hf_ftp_command_response_bytes = -1;
 static int hf_ftp_command_response_first_frame_num = -1;
 static int hf_ftp_command_response_last_frame_num = -1;
 static int hf_ftp_command_response_duration = -1;
+static int hf_ftp_command_response_kbps = -1;
 static int hf_ftp_command_setup_frame = -1;
 static int hf_ftp_command_command_frame = -1;
 static int hf_ftp_command_command = -1;
@@ -177,6 +167,7 @@ typedef struct ftp_data_conversation_t
     guint         last_frame_num;
     nstime_t      last_frame_time;
     guint         frames_seen;
+    guint         bytes_seen;
 } ftp_data_conversation_t;
 
 /* Data to associate with individual FTP frame */
@@ -230,7 +221,7 @@ static void create_and_link_data_conversation(packet_info *pinfo,
                                               const char *method)
 {
     /* Only to do on first pass */
-    if (pinfo->fd->flags.visited) {
+    if (pinfo->fd->visited) {
         return;
     }
 
@@ -894,7 +885,7 @@ dissect_ftp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
     ftp_conversation_t *p_ftp_conv = find_or_create_ftp_conversation(pinfo);
 
     /* Store the current working directory */
-    if (!pinfo->fd->flags.visited) {
+    if (!pinfo->fd->visited) {
         store_directory_in_packet(pinfo, p_ftp_conv);
     }
 
@@ -1015,13 +1006,13 @@ dissect_ftp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
              * Responses to CWD command.
              */
             if (code == 250) {
-                if (!pinfo->fd->flags.visited) {
+                if (!pinfo->fd->visited) {
                     if (p_ftp_conv && p_ftp_conv->last_command) {
                         /* Explicit Change Working Directory command */
                         if (strncmp(p_ftp_conv->last_command, "CWD ", 4) == 0) {
                             process_cwd_success(p_ftp_conv, p_ftp_conv->last_command+4);
                             /* Update path in packet */
-                            if (!pinfo->fd->flags.visited) {
+                            if (!pinfo->fd->visited) {
                                 store_directory_in_packet(pinfo, p_ftp_conv);
                             }
                         }
@@ -1029,7 +1020,7 @@ dissect_ftp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
                         else if (strncmp(p_ftp_conv->last_command, "CDUP", 4) == 0) {
                             process_cwd_success(p_ftp_conv, "..");
                             /* Update path in packet */
-                            if (!pinfo->fd->flags.visited) {
+                            if (!pinfo->fd->visited) {
                                 store_directory_in_packet(pinfo, p_ftp_conv);
                             }
                         }
@@ -1041,13 +1032,13 @@ dissect_ftp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
              * Responses to PWD command. Overwrite whatever is stored - this is the truth!
              */
             if (code == 257) {
-                if (!pinfo->fd->flags.visited) {
+                if (!pinfo->fd->visited) {
                     if (p_ftp_conv && linelen >= 4) {
                         /* Want directory name, which will be between " " */
                         process_pwd_success(p_ftp_conv, line+4, linelen-4, pinfo, pi);
 
                         /* Update path in packet */
-                        if (!pinfo->fd->flags.visited) {
+                        if (!pinfo->fd->visited) {
                             store_directory_in_packet(pinfo, p_ftp_conv);
                         }
                     }
@@ -1259,7 +1250,7 @@ dissect_ftp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
     }
 
     /* If this is a command resulting in an ftp-data stream, show details */
-    if (pinfo->fd->flags.visited) {
+    if (pinfo->fd->visited) {
         /* Look up what has been stored for this frame */
         ftp_data_conversation_t *ftp_data =
                 (ftp_data_conversation_t *)g_hash_table_lookup(ftp_command_to_data_hash, GUINT_TO_POINTER(pinfo->num));
@@ -1271,6 +1262,11 @@ dissect_ftp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
                                          tvb, 0, 0, ftp_data->frames_seen);
                 PROTO_ITEM_SET_GENERATED(ti);
 
+                /* Number of bytes */
+                ti = proto_tree_add_uint(tree, hf_ftp_command_response_bytes,
+                                         tvb, 0, 0, ftp_data->bytes_seen);
+                PROTO_ITEM_SET_GENERATED(ti);
+
                 /* First frame */
                 ti = proto_tree_add_uint(tree, hf_ftp_command_response_first_frame_num,
                                          tvb, 0, 0, ftp_data->first_frame_num);
@@ -1294,6 +1290,12 @@ dissect_ftp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
                     ti = proto_tree_add_uint(tree, hf_ftp_command_response_duration,
                                          tvb, 0, 0, gap_ms);
                     PROTO_ITEM_SET_GENERATED(ti);
+
+                    /* Bitrate (kbps)*/
+                    guint bitrate = (guint)(((ftp_data->bytes_seen*8.0)/(gap_ms/1000.0))/1000);
+                    ti = proto_tree_add_uint(tree, hf_ftp_command_response_kbps,
+                                             tvb, offset, 0, bitrate);
+                    PROTO_ITEM_SET_GENERATED(ti);
                 }
 
                 ti = proto_tree_add_uint(tree, hf_ftp_command_setup_frame,
@@ -1347,7 +1349,7 @@ dissect_ftpdata(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data
 
         if (p_ftp_data_conv) {
             /* First time around, update info. */
-            if (!pinfo->fd->flags.visited) {
+            if (!pinfo->fd->visited) {
                 if (!p_ftp_data_conv->first_frame_num) {
                     p_ftp_data_conv->first_frame_num = pinfo->num;
                     p_ftp_data_conv->first_frame_time = pinfo->abs_ts;
@@ -1357,6 +1359,7 @@ dissect_ftpdata(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data
                     p_ftp_data_conv->last_frame_time = pinfo->abs_ts;
                 }
                 p_ftp_data_conv->frames_seen++;
+                p_ftp_data_conv->bytes_seen += tvb_reported_length(tvb);
 
                 /* Also store setup_frame here for benefit of ftp (control) */
                 p_ftp_data_conv->setup_frame = p_conv->setup_frame;
@@ -1541,11 +1544,21 @@ proto_register_ftp(void)
             FT_UINT32, BASE_DEC|BASE_UNIT_STRING, &units_milliseconds, 0,
             "Duration of command response in ms", HFILL }},
 
+        { &hf_ftp_command_response_kbps,
+          { "Response bitrate", "ftp.command-response.bitrate",
+            FT_UINT32, BASE_DEC|BASE_UNIT_STRING, &units_kbps, 0,
+            "Bitrate of command response", HFILL }},
+
         { &hf_ftp_command_response_frames,
           { "Command response frames", "ftp.command-response.frames",
             FT_UINT32, BASE_DEC, NULL, 0,
             "Number of frames seen in resulting ftp-data stream", HFILL }},
 
+        { &hf_ftp_command_response_bytes,
+          { "Command response bytes", "ftp.command-response.bytes",
+            FT_UINT32, BASE_DEC, NULL, 0,
+            "Number of bytes seen in resulting ftp-data stream", HFILL }},
+
         { &hf_ftp_command_setup_frame,
           { "Setup frame", "ftp.setup-frame",
             FT_FRAMENUM, BASE_NONE, FRAMENUM_TYPE(FT_FRAMENUM_REQUEST), 0,
