@@ -6,19 +6,7 @@
  * By Gerald Combs <gerald@wireshark.org>
  * Copyright 1998 Gerald Combs
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 
@@ -218,13 +206,13 @@ dissect_hpfeeds_publish_pdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 
 static void hpfeeds_stats_tree_init(stats_tree* st)
 {
-    st_node_channels_payload = stats_tree_create_node(st, st_str_channels_payload, 0, TRUE);
+    st_node_channels_payload = stats_tree_create_node(st, st_str_channels_payload, 0, STAT_DT_INT, TRUE);
     st_node_opcodes = stats_tree_create_pivot(st, st_str_opcodes, 0);
 
     channels_list = wmem_list_new(wmem_epan_scope());
 }
 
-static int hpfeeds_stats_tree_packet(stats_tree* st _U_, packet_info* pinfo _U_, epan_dissect_t* edt _U_, const void* p)
+static tap_packet_status hpfeeds_stats_tree_packet(stats_tree* st _U_, packet_info* pinfo _U_, epan_dissect_t* edt _U_, const void* p)
 {
     const struct HpfeedsTap *pi = (const struct HpfeedsTap *)p;
     wmem_list_frame_t* head = wmem_list_head(channels_list);
@@ -245,17 +233,17 @@ static int hpfeeds_stats_tree_packet(stats_tree* st _U_, packet_info* pinfo _U_,
             ch_node = (struct channel_node*)wmem_alloc0(wmem_file_scope(), sizeof(struct channel_node));
             ch_node->channel = wmem_strdup(wmem_file_scope(), pi->channel);
             ch_node->st_node_channel_payload = stats_tree_create_node(st, ch_node->channel,
-                st_node_channels_payload, FALSE);
+                st_node_channels_payload, STAT_DT_INT, FALSE);
             wmem_list_append(channels_list, ch_node);
         }
 
-        avg_stat_node_add_value(st, st_str_channels_payload, 0, FALSE, pi->payload_size);
-        avg_stat_node_add_value(st, ch_node->channel, 0, FALSE, pi->payload_size);
+        avg_stat_node_add_value_int(st, st_str_channels_payload, 0, FALSE, pi->payload_size);
+        avg_stat_node_add_value_int(st, ch_node->channel, 0, FALSE, pi->payload_size);
     }
 
     stats_tree_tick_pivot(st, st_node_opcodes,
             val_to_str(pi->opcode, opcode_vals, "Unknown opcode (%d)"));
-    return 1;
+    return TAP_PACKET_REDRAW;
 }
 
 static void
