@@ -11,19 +11,7 @@
  * By Gerald Combs <gerald@wireshark.org>
  * Copyright 1998 Gerald Combs
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  */
 
@@ -677,7 +665,7 @@ dissect_pn532(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data)
     key[4].length = 0;
     key[4].key = NULL;
 
-    if (!pinfo->fd->flags.visited && !(cmd & 0x01)) {
+    if (!pinfo->fd->visited && !(cmd & 0x01)) {
         command_data = wmem_new(wmem_file_scope(), command_data_t);
         command_data->bus_id = bus_id;
         command_data->device_address = device_address;
@@ -719,7 +707,7 @@ dissect_pn532(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data)
             if (command_data && (command_data->response_frame_number == 0 ||
                     command_data->response_frame_number == pinfo->num)) {
 
-                if (!pinfo->fd->flags.visited && command_data->response_frame_number == 0) {
+                if (!pinfo->fd->visited && command_data->response_frame_number == 0) {
                     command_data->response_frame_number = pinfo->num;
                 }
 
