@@ -13,6 +13,7 @@
 
 #include "packet-dcerpc.h"
 #include "packet-smb.h"
+#include "packet-ntlmssp.h"
 
 /* SMB2 command codes. With MSVC and a
  * libwireshark.dll, we need a special declaration.
@@ -57,6 +58,7 @@ typedef struct _smb2_saved_info_t {
 	guint64 msg_id;
 	guint32 frame_req, frame_res;
 	nstime_t req_time;
+	guint8 *preauth_hash_req, *preauth_hash_res;
 	smb2_fid_info_t *file;
 	e_ctx_hnd policy_hnd; 		/* for eo_smb tracking */
 	smb_eo_t	*eo_info_t;	/* for storing eo_smb infos */
@@ -73,6 +75,8 @@ typedef struct _smb2_tid_info_t {
 	char *name;
 } smb2_tid_info_t;
 
+#define SMB2_PREAUTH_HASH_SIZE 64
+
 typedef struct _smb2_sesid_info_t {
 	guint64 sesid;		/* *host* byte order - not necessarily little-endian! */
 	guint32 auth_frame;
@@ -80,9 +84,11 @@ typedef struct _smb2_sesid_info_t {
 	char *domain_name;
 	char *host_name;
 	guint16 server_port;
+	guint8 session_key[NTLMSSP_KEY_LEN];
 	guint8 client_decryption_key[16];
 	guint8 server_decryption_key[16];
-	GHashTable *tids;
+	wmem_map_t *tids;
+	guint8 preauth_hash[SMB2_PREAUTH_HASH_SIZE];
 } smb2_sesid_info_t;
 
 /* Structure to keep track of conversations and the hash tables.
@@ -96,6 +102,12 @@ typedef struct _smb2_conv_info_t {
 	GHashTable *fids;
 	/* table to store some infos for smb export object */
 	GHashTable *files;
+	guint16 dialect;
+
+	/* preauth hash before session setup */
+	guint8 *preauth_hash_current;
+	guint8 preauth_hash_con[SMB2_PREAUTH_HASH_SIZE];
+	guint8 preauth_hash_ses[SMB2_PREAUTH_HASH_SIZE];
 } smb2_conv_info_t;
 
 
