@@ -20,6 +20,8 @@
 #include <epan/packet.h>
 #include <epan/strutil.h>
 
+#include "packet-syslog.h"
+
 #define UDP_PORT_SYSLOG 514
 
 #define PRIORITY_MASK 0x0007  /* 0000 0111 */
@@ -31,15 +33,7 @@ void proto_register_syslog(void);
 /* The maximum number if priority digits to read in. */
 #define MAX_DIGITS 3
 
-#define LEVEL_EMERG     0
-#define LEVEL_ALERT     1
-#define LEVEL_CRIT      2
-#define LEVEL_ERR       3
-#define LEVEL_WARNING   4
-#define LEVEL_NOTICE    5
-#define LEVEL_INFO      6
-#define LEVEL_DEBUG     7
-static const value_string short_lev[] = {
+static const value_string short_level_vals[] = {
   { LEVEL_EMERG,        "EMERG" },
   { LEVEL_ALERT,        "ALERT" },
   { LEVEL_CRIT,         "CRIT" },
@@ -51,31 +45,7 @@ static const value_string short_lev[] = {
   { 0, NULL }
 };
 
-#define FAC_KERN        0
-#define FAC_USER        1
-#define FAC_MAIL        2
-#define FAC_DAEMON      3
-#define FAC_AUTH        4
-#define FAC_SYSLOG      5
-#define FAC_LPR         6
-#define FAC_NEWS        7
-#define FAC_UUCP        8
-#define FAC_CRON        9
-#define FAC_AUTHPRIV    10
-#define FAC_FTP         11
-#define FAC_NTP         12
-#define FAC_LOGAUDIT    13
-#define FAC_LOGALERT    14
-#define FAC_CRON_SOL    15
-#define FAC_LOCAL0      16
-#define FAC_LOCAL1      17
-#define FAC_LOCAL2      18
-#define FAC_LOCAL3      19
-#define FAC_LOCAL4      20
-#define FAC_LOCAL5      21
-#define FAC_LOCAL6      22
-#define FAC_LOCAL7      23
-static const value_string short_fac[] = {
+static const value_string short_facility_vals[] = {
   { FAC_KERN,           "KERN" },
   { FAC_USER,           "USER" },
   { FAC_MAIL,           "MAIL" },
@@ -103,53 +73,23 @@ static const value_string short_fac[] = {
   { 0, NULL }
 };
 
-static const value_string long_lev[] = {
-  { LEVEL_EMERG,        "EMERG - system is unusable" },
-  { LEVEL_ALERT,        "ALERT - action must be taken immediately" },
-  { LEVEL_CRIT,         "CRIT - critical conditions" },
-  { LEVEL_ERR,          "ERR - error conditions" },
-  { LEVEL_WARNING,      "WARNING - warning conditions" },
-  { LEVEL_NOTICE,       "NOTICE - normal but significant condition" },
-  { LEVEL_INFO,         "INFO - informational" },
-  { LEVEL_DEBUG,        "DEBUG - debug-level messages" },
-  { 0, NULL }
-};
-
-static const value_string long_fac[] = {
-  { FAC_KERN,           "KERN - kernel messages" },
-  { FAC_USER,           "USER - random user-level messages" },
-  { FAC_MAIL,           "MAIL - mail system" },
-  { FAC_DAEMON,         "DAEMON - system daemons" },
-  { FAC_AUTH,           "AUTH - security/authorization messages" },
-  { FAC_SYSLOG,         "SYSLOG - messages generated internally by syslogd" },
-  { FAC_LPR,            "LPR - line printer subsystem" },
-  { FAC_NEWS,           "NEWS - network news subsystem" },
-  { FAC_UUCP,           "UUCP - UUCP subsystem" },
-  { FAC_CRON,           "CRON - clock daemon (BSD, Linux)" },
-  { FAC_AUTHPRIV,       "AUTHPRIV - security/authorization messages (private)" },
-  { FAC_FTP,            "FTP - ftp daemon" },
-  { FAC_NTP,            "NTP - ntp subsystem" },
-  { FAC_LOGAUDIT,       "LOGAUDIT - log audit" },
-  { FAC_LOGALERT,       "LOGALERT - log alert" },
-  { FAC_CRON_SOL,       "CRON - clock daemon (Solaris)" },
-  { FAC_LOCAL0,         "LOCAL0 - reserved for local use" },
-  { FAC_LOCAL1,         "LOCAL1 - reserved for local use" },
-  { FAC_LOCAL2,         "LOCAL2 - reserved for local use" },
-  { FAC_LOCAL3,         "LOCAL3 - reserved for local use" },
-  { FAC_LOCAL4,         "LOCAL4 - reserved for local use" },
-  { FAC_LOCAL5,         "LOCAL5 - reserved for local use" },
-  { FAC_LOCAL6,         "LOCAL6 - reserved for local use" },
-  { FAC_LOCAL7,         "LOCAL7 - reserved for local use" },
-  { 0, NULL }
-};
-
 static gint proto_syslog = -1;
 static gint hf_syslog_level = -1;
 static gint hf_syslog_facility = -1;
 static gint hf_syslog_msg = -1;
 static gint hf_syslog_msu_present = -1;
+static gint hf_syslog_version = -1;
+static gint hf_syslog_timestamp = -1;
+static gint hf_syslog_timestamp_old = -1;
+static gint hf_syslog_hostname = -1;
+static gint hf_syslog_appname = -1;
+static gint hf_syslog_procid = -1;
+static gint hf_syslog_msgid = -1;
+static gint hf_syslog_msgid_utf8 = -1;
+static gint hf_syslog_msgid_bom = -1;
 
 static gint ett_syslog = -1;
+static gint ett_syslog_msg = -1;
 
 static dissector_handle_t syslog_handle;
 
@@ -211,6 +151,82 @@ mtp3_msu_present(tvbuff_t *tvb, packet_info *pinfo, gint fac, gint level, const
   return(mtp3_tvb);
 }
 
+static gboolean dissect_syslog_info(proto_tree* tree, tvbuff_t* tvb, guint* offset, gint hfindex)
+{
+  gint end_offset = tvb_find_guint8(tvb, *offset, -1, ' ');
+  if (end_offset == -1)
+    return FALSE;
+  proto_tree_add_item(tree, hfindex, tvb, *offset, end_offset - *offset, ENC_NA);
+  *offset = end_offset + 1;
+  return TRUE;
+}
+
+/* Dissect message as defined in RFC5424 */
+static void
+dissect_syslog_message(proto_tree* tree, tvbuff_t* tvb, guint offset)
+{
+  gint end_offset;
+
+  if (!dissect_syslog_info(tree, tvb, &offset, hf_syslog_version))
+    return;
+
+  end_offset = tvb_find_guint8(tvb, offset, -1, ' ');
+  if (end_offset == -1)
+    return;
+  if ((guint)end_offset != offset) {
+    /* do not call proto_tree_add_time_item with a length of 0 */
+    proto_tree_add_time_item(tree, hf_syslog_timestamp, tvb, offset, end_offset - offset, ENC_ISO_8601_DATE_TIME,
+      NULL, NULL, NULL);
+  }
+  offset = end_offset + 1;
+
+  if (!dissect_syslog_info(tree, tvb, &offset, hf_syslog_hostname))
+    return;
+  if (!dissect_syslog_info(tree, tvb, &offset, hf_syslog_appname))
+    return;
+  if (!dissect_syslog_info(tree, tvb, &offset, hf_syslog_procid))
+    return;
+  if (tvb_get_guint24(tvb, offset, ENC_BIG_ENDIAN) == 0xefbbbf) {
+    proto_tree_add_item(tree, hf_syslog_msgid_bom, tvb, offset, 3, ENC_BIG_ENDIAN);
+    offset += 3;
+    proto_tree_add_item(tree, hf_syslog_msgid_utf8, tvb, offset, tvb_reported_length_remaining(tvb, offset), ENC_UTF_8|ENC_NA);
+  } else {
+    proto_tree_add_item(tree, hf_syslog_msgid, tvb, offset, tvb_reported_length_remaining(tvb, offset), ENC_ASCII|ENC_NA);
+  }
+}
+
+/* Dissect message as defined in RFC3164 */
+static void
+dissect_rfc3164_syslog_message(proto_tree* tree, tvbuff_t* tvb, guint offset)
+{
+  guint tvb_offset = 0;
+
+  /* Simple check if the first 16 bytes look like TIMESTAMP "Mmm dd hh:mm:ss"
+   * by checking for spaces and colons. Otherwise return without processing
+   * the message. */
+  if (tvb_get_guint8(tvb, offset + 3) == ' ' && tvb_get_guint8(tvb, offset + 6) == ' ' &&
+        tvb_get_guint8(tvb, offset + 9) == ':' && tvb_get_guint8(tvb, offset + 12) == ':' &&
+        tvb_get_guint8(tvb, offset + 15) == ' ') {
+    proto_tree_add_item(tree, hf_syslog_timestamp_old, tvb, offset, 15, ENC_ASCII|ENC_NA);
+    offset += 16;
+  } else {
+    return;
+  }
+
+  if (!dissect_syslog_info(tree, tvb, &offset, hf_syslog_hostname))
+    return;
+  for (tvb_offset=offset; tvb_offset < offset+32; tvb_offset++){
+    guint8 octet;
+    octet = tvb_get_guint8(tvb, tvb_offset);
+    if (!g_ascii_isalnum(octet)){
+      proto_tree_add_item(tree, hf_syslog_procid, tvb, offset, tvb_offset - offset, ENC_ASCII|ENC_NA);
+      offset = tvb_offset;
+      break;
+    }
+  }
+  proto_tree_add_item(tree, hf_syslog_msgid, tvb, offset, tvb_reported_length_remaining(tvb, offset), ENC_ASCII|ENC_NA);
+}
+
 /* The message format is defined in RFC 3164 */
 static int
 dissect_syslog(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
@@ -219,6 +235,7 @@ dissect_syslog(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _
   gint msg_off = 0, msg_len, reported_msg_len;
   proto_item *ti;
   proto_tree *syslog_tree;
+  proto_tree *syslog_message_tree;
   const char *msg_str;
   tvbuff_t *mtp3_tvb;
 
@@ -250,8 +267,8 @@ dissect_syslog(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _
   if (mtp3_tvb == NULL) {
     if (pri >= 0) {
       col_add_fstr(pinfo->cinfo, COL_INFO, "%s.%s: %s",
-        val_to_str_const(fac, short_fac, "UNKNOWN"),
-        val_to_str_const(lev, short_lev, "UNKNOWN"), msg_str);
+        val_to_str_const(fac, short_facility_vals, "UNKNOWN"),
+        val_to_str_const(lev, short_level_vals, "UNKNOWN"), msg_str);
     } else {
       col_add_str(pinfo->cinfo, COL_INFO, msg_str);
     }
@@ -261,8 +278,8 @@ dissect_syslog(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _
     if (pri >= 0) {
       ti = proto_tree_add_protocol_format(tree, proto_syslog, tvb, 0, -1,
         "Syslog message: %s.%s: %s",
-        val_to_str_const(fac, short_fac, "UNKNOWN"),
-        val_to_str_const(lev, short_lev, "UNKNOWN"), msg_str);
+        val_to_str_const(fac, short_facility_vals, "UNKNOWN"),
+        val_to_str_const(lev, short_level_vals, "UNKNOWN"), msg_str);
     } else {
       ti = proto_tree_add_protocol_format(tree, proto_syslog, tvb, 0, -1,
         "Syslog message: (unknown): %s", msg_str);
@@ -274,8 +291,19 @@ dissect_syslog(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _
       proto_tree_add_uint(syslog_tree, hf_syslog_level, tvb, 0,
         msg_off, pri);
     }
-    proto_tree_add_item(syslog_tree, hf_syslog_msg, tvb, msg_off,
-      msg_len, ENC_ASCII|ENC_NA);
+    ti = proto_tree_add_item(syslog_tree, hf_syslog_msg, tvb, msg_off,
+      msg_len, ENC_UTF_8|ENC_NA);
+    syslog_message_tree = proto_item_add_subtree(ti, ett_syslog_msg);
+
+    /* RFC5424 defines a version field which is currently defined as '1'
+     * followed by a space (0x3120). Otherwise the message is probable
+     * a RFC3164 message.
+     */
+    if (msg_len > 2 && tvb_get_ntohs(tvb, msg_off) == 0x3120) {
+      dissect_syslog_message(syslog_message_tree, tvb, msg_off);
+    } else if ( msg_len > 15) {
+      dissect_rfc3164_syslog_message(syslog_message_tree, tvb, msg_off);
+    }
 
     if (mtp3_tvb) {
       proto_item *mtp3_item;
@@ -301,12 +329,12 @@ void proto_register_syslog(void)
   static hf_register_info hf[] = {
     { &hf_syslog_facility,
       { "Facility",           "syslog.facility",
-        FT_UINT8, BASE_DEC, VALS(long_fac), FACILITY_MASK,
+        FT_UINT8, BASE_DEC, VALS(syslog_facility_vals), FACILITY_MASK,
         "Message facility", HFILL }
     },
     { &hf_syslog_level,
       { "Level",              "syslog.level",
-        FT_UINT8, BASE_DEC, VALS(long_lev), PRIORITY_MASK,
+        FT_UINT8, BASE_DEC, VALS(syslog_level_vals), PRIORITY_MASK,
         "Message level", HFILL }
     },
     { &hf_syslog_msg,
@@ -319,12 +347,67 @@ void proto_register_syslog(void)
         FT_BOOLEAN, BASE_NONE, NULL, 0x0,
         "True if an SS7 MSU was detected in the syslog message",
         HFILL }
+    },
+    { &hf_syslog_version,
+      { "Syslog version", "syslog.version",
+        FT_STRING, BASE_NONE, NULL, 0x0,
+        NULL,
+        HFILL }
+    },
+    { &hf_syslog_timestamp,
+      { "Syslog timestamp", "syslog.timestamp",
+        FT_ABSOLUTE_TIME, ABSOLUTE_TIME_UTC, NULL, 0x0,
+        NULL,
+        HFILL }
+    },
+    { &hf_syslog_timestamp_old,
+      { "Syslog timestamp (RFC3164)", "syslog.timestamp_rfc3164",
+        FT_STRING, ENC_ASCII, NULL, 0x0,
+        NULL,
+        HFILL }
+    },
+    { &hf_syslog_hostname,
+      { "Syslog hostname", "syslog.hostname",
+        FT_STRING, ENC_ASCII, NULL, 0x0,
+        NULL,
+        HFILL }
+    },
+    { &hf_syslog_appname,
+      { "Syslog app name", "syslog.appname",
+        FT_STRING, ENC_ASCII, NULL, 0x0,
+        "The name of the app that generated this message",
+        HFILL }
+    },
+    { &hf_syslog_procid,
+      { "Syslog process id", "syslog.procid",
+        FT_STRING, ENC_ASCII, NULL, 0x0,
+        NULL,
+        HFILL }
+    },
+    { &hf_syslog_msgid,
+      { "Syslog message id", "syslog.msgid",
+        FT_STRING, ENC_ASCII, NULL, 0x0,
+        NULL,
+        HFILL }
+    },
+    { &hf_syslog_msgid_utf8,
+      { "Syslog message id", "syslog.msgid",
+        FT_STRING, STR_UNICODE, NULL, 0x0,
+        NULL,
+        HFILL }
+    },
+    { &hf_syslog_msgid_bom,
+      { "Syslog BOM", "syslog.msgid.bom",
+        FT_UINT24, BASE_HEX, NULL, 0x0,
+        NULL,
+        HFILL }
     }
   };
 
   /* Setup protocol subtree array */
   static gint *ett[] = {
     &ett_syslog,
+    &ett_syslog_msg
   };
 
   /* Register the protocol name and description */
