@@ -16,7 +16,6 @@
 #include <wsutil/interface.h>
 #include <wsutil/strtoi.h>
 #include <wsutil/filesystem.h>
-#include <wsutil/glib-compat.h>
 #include <wsutil/privileges.h>
 #include <extcap/ssh-base.h>
 #include <writecap/pcapio.h>
@@ -25,6 +24,8 @@
 #include <string.h>
 #include <fcntl.h>
 
+#include <cli_main.h>
+
 #define CISCODUMP_VERSION_MAJOR "1"
 #define CISCODUMP_VERSION_MINOR "0"
 #define CISCODUMP_VERSION_RELEASE "0"
@@ -68,6 +69,7 @@ enum {
 	OPT_REMOTE_FILTER,
 	OPT_SSHKEY,
 	OPT_SSHKEY_PASSPHRASE,
+	OPT_PROXYCOMMAND,
 	OPT_REMOTE_COUNT
 };
 
@@ -251,7 +253,11 @@ static void ssh_loop_read(ssh_channel channel, FILE* fp, const guint32 count)
 
 			if (status == CISCODUMP_PARSER_END_PACKET) {
 				/* dump the packet to the pcap file */
-				libpcap_write_packet(fp, curtime, (guint32)(curtime / 1000), packet_size, packet_size, packet, &bytes_written, &err);
+				if (!libpcap_write_packet(fp, curtime, (guint32)(curtime / 1000), packet_size,
+						packet_size, packet, &bytes_written, &err)) {
+					g_debug("Error in libpcap_write_packet(): %s", g_strerror(err));
+					break;
+				}
 				g_debug("Dumped packet %lu size: %u", packets, packet_size);
 				packet_size = 0;
 				status = CISCODUMP_PARSER_STARTING;
@@ -402,8 +408,7 @@ error:
 	return NULL;
 }
 
-static int ssh_open_remote_connection(const char* hostname, const unsigned int port, const char* username, const char* password,
-	const char* sshkey, const char* sshkey_passphrase, const char* iface, const char* cfilter,
+static int ssh_open_remote_connection(const ssh_params_t* ssh_params, const char* iface, const char* cfilter,
 	const guint32 count, const char* fifo)
 {
 	ssh_session sshs;
@@ -423,7 +428,7 @@ static int ssh_open_remote_connection(const char* hostname, const unsigned int p
 		}
 	}
 
-	sshs = create_ssh_connection(hostname, port, username, password, sshkey, sshkey_passphrase, &err_info);
+	sshs = create_ssh_connection(ssh_params, &err_info);
 	if (!sshs) {
 		g_warning("Error creating connection: %s", err_info);
 		goto cleanup;
@@ -473,33 +478,36 @@ static int list_config(char *interface, unsigned int remote_port)
 
 	printf("arg {number=%u}{call=--remote-host}{display=Remote SSH server address}"
 		"{type=string}{tooltip=The remote SSH host. It can be both "
-		"an IP address or a hostname}{required=true}\n", inc++);
+		"an IP address or a hostname}{required=true}{group=Server}\n", inc++);
 	printf("arg {number=%u}{call=--remote-port}{display=Remote SSH server port}"
 		"{type=unsigned}{default=22}{tooltip=The remote SSH host port (1-65535)}"
-		"{range=1,65535}\n", inc++);
+		"{range=1,65535}{group=Server}\n", inc++);
 	printf("arg {number=%u}{call=--remote-username}{display=Remote SSH server username}"
 		"{type=string}{default=%s}{tooltip=The remote SSH username. If not provided, "
-		"the current user will be used}\n", inc++, g_get_user_name());
+		"the current user will be used}{group=Authentication}\n", inc++, g_get_user_name());
 	printf("arg {number=%u}{call=--remote-password}{display=Remote SSH server password}"
 		"{type=password}{tooltip=The SSH password, used when other methods (SSH agent "
-		"or key files) are unavailable.}\n", inc++);
+		"or key files) are unavailable.}{group=Authentication}\n", inc++);
 	printf("arg {number=%u}{call=--sshkey}{display=Path to SSH private key}"
-		"{type=fileselect}{tooltip=The path on the local filesystem of the private ssh key}\n",
-		inc++);
+		"{type=fileselect}{tooltip=The path on the local filesystem of the private ssh key}"
+		"{group=Authentication}\n", inc++);
+	printf("arg {number=%u}{call=--proxycommand}{display=ProxyCommand}"
+		"{type=string}{tooltip=The command to use as proxy for the SSH connection}"
+		"{group=Authentication}\n", inc++);
 	printf("arg {number=%u}{call--sshkey-passphrase}{display=SSH key passphrase}"
-		"{type=password}{tooltip=Passphrase to unlock the SSH private key}\n",
-		inc++);
+		"{type=password}{tooltip=Passphrase to unlock the SSH private key}"
+		"{group=Authentication\n", inc++);
 	printf("arg {number=%u}{call=--remote-interface}{display=Remote interface}"
 		"{type=string}{required=true}{tooltip=The remote network interface used for capture"
-		"}\n", inc++);
+		"}{group=Capture}\n", inc++);
 	printf("arg {number=%u}{call=--remote-filter}{display=Remote capture filter}"
 		"{type=string}{tooltip=The remote capture filter}", inc++);
 	if (ipfilter)
 		printf("{default=%s}", ipfilter);
-	printf("\n");
+	printf("{group=Capture}\n");
 	printf("arg {number=%u}{call=--remote-count}{display=Packets to capture}"
-		"{type=unsigned}{required=true}{tooltip=The number of remote packets to capture.}\n",
-		inc++);
+		"{type=unsigned}{required=true}{tooltip=The number of remote packets to capture.}"
+		"{group=Capture}\n", inc++);
 
 	extcap_config_debug(&inc);
 
@@ -508,18 +516,13 @@ static int list_config(char *interface, unsigned int remote_port)
 	return EXIT_SUCCESS;
 }
 
-int main(int argc, char **argv)
+int main(int argc, char *argv[])
 {
 	char* init_progfile_dir_error;
 	int result;
 	int option_idx = 0;
-	char* remote_host = NULL;
-	guint16 remote_port = 22;
-	char* remote_username = NULL;
-	char* remote_password = NULL;
+	ssh_params_t* ssh_params = ssh_params_new();
 	char* remote_interface = NULL;
-	char* sshkey = NULL;
-	char* sshkey_passphrase = NULL;
 	char* remote_filter = NULL;
 	guint32 count = 0;
 	int ret = EXIT_FAILURE;
@@ -529,8 +532,6 @@ int main(int argc, char **argv)
 
 #ifdef _WIN32
 	WSADATA wsaData;
-
-	attach_parent_console();
 #endif  /* _WIN32 */
 
 	/*
@@ -542,7 +543,7 @@ int main(int argc, char **argv)
 	 * Attempt to get the pathname of the directory containing the
 	 * executable file.
 	 */
-	init_progfile_dir_error = init_progfile_dir(argv[0], NULL);
+	init_progfile_dir_error = init_progfile_dir(argv[0]);
 	if (init_progfile_dir_error != NULL) {
 		g_warning("Can't get pathname of directory containing the captype program: %s.",
 			init_progfile_dir_error);
@@ -575,6 +576,7 @@ int main(int argc, char **argv)
 		"If not specified, ssh-agent and ssh-key are used");
 	extcap_help_add_option(extcap_conf, "--sshkey <public key path>", "the path of the ssh key");
 	extcap_help_add_option(extcap_conf, "--sshkey-passphrase <public key passphrase>", "the passphrase to unlock public ssh");
+	extcap_help_add_option(extcap_conf, "--proxycommand <proxy command>", "the command to use as proxy the the ssh connection");
 	extcap_help_add_option(extcap_conf, "--remote-interface <iface>", "the remote capture interface");
 	extcap_help_add_option(extcap_conf, "--remote-filter <filter>", "a filter for remote capture "
 		"(default: don't capture data for lal interfaces IPs)");
@@ -601,39 +603,44 @@ int main(int argc, char **argv)
 			goto end;
 
 		case OPT_REMOTE_HOST:
-			g_free(remote_host);
-			remote_host = g_strdup(optarg);
+			g_free(ssh_params->host);
+			ssh_params->host = g_strdup(optarg);
 			break;
 
 		case OPT_REMOTE_PORT:
-			if (!ws_strtou16(optarg, NULL, &remote_port) || remote_port == 0) {
+			if (!ws_strtou16(optarg, NULL, &ssh_params->port) || ssh_params->port == 0) {
 				g_warning("Invalid port: %s", optarg);
 				goto end;
 			}
 			break;
 
 		case OPT_REMOTE_USERNAME:
-			g_free(remote_username);
-			remote_username = g_strdup(optarg);
+			g_free(ssh_params->username);
+			ssh_params->username = g_strdup(optarg);
 			break;
 
 		case OPT_REMOTE_PASSWORD:
-			g_free(remote_password);
-			remote_password = g_strdup(optarg);
+			g_free(ssh_params->password);
+			ssh_params->password = g_strdup(optarg);
 			memset(optarg, 'X', strlen(optarg));
 			break;
 
 		case OPT_SSHKEY:
-			g_free(sshkey);
-			sshkey = g_strdup(optarg);
+			g_free(ssh_params->sshkey_path);
+			ssh_params->sshkey_path = g_strdup(optarg);
 			break;
 
 		case OPT_SSHKEY_PASSPHRASE:
-			g_free(sshkey_passphrase);
-			sshkey_passphrase = g_strdup(optarg);
+			g_free(ssh_params->sshkey_passphrase);
+			ssh_params->sshkey_passphrase = g_strdup(optarg);
 			memset(optarg, 'X', strlen(optarg));
 			break;
 
+		case OPT_PROXYCOMMAND:
+			g_free(ssh_params->proxycommand);
+			ssh_params->proxycommand = g_strdup(optarg);
+			break;
+
 		case OPT_REMOTE_INTERFACE:
 			g_free(remote_interface);
 			remote_interface = g_strdup(optarg);
@@ -677,7 +684,7 @@ int main(int argc, char **argv)
 	}
 
 	if (extcap_conf->show_config) {
-		ret = list_config(extcap_conf->interface, remote_port);
+		ret = list_config(extcap_conf->interface, ssh_params->port);
 		goto end;
 	}
 
@@ -690,7 +697,7 @@ int main(int argc, char **argv)
 #endif  /* _WIN32 */
 
 	if (extcap_conf->capture) {
-		if (!remote_host) {
+		if (!ssh_params->host) {
 			g_warning("Missing parameter: --remote-host");
 			goto end;
 		}
@@ -703,9 +710,8 @@ int main(int argc, char **argv)
 			g_warning("ERROR: count of packets must be specified (--remote-count)");
 			goto end;
 		}
-
-		ret = ssh_open_remote_connection(remote_host, remote_port, remote_username,
-			remote_password, sshkey, sshkey_passphrase, remote_interface,
+		ssh_params->debug = extcap_conf->debug;
+		ret = ssh_open_remote_connection(ssh_params, remote_interface,
 			remote_filter, count, extcap_conf->fifo);
 	} else {
 		g_debug("You should not come here... maybe some parameter missing?");
@@ -713,28 +719,13 @@ int main(int argc, char **argv)
 	}
 
 end:
-	g_free(remote_host);
-	g_free(remote_username);
-	g_free(remote_password);
+	ssh_params_free(ssh_params);
 	g_free(remote_interface);
-	g_free(sshkey);
-	g_free(sshkey_passphrase);
 	g_free(remote_filter);
 	extcap_base_cleanup(&extcap_conf);
 	return ret;
 }
 
-#ifdef _WIN32
-int _stdcall
-WinMain (struct HINSTANCE__ *hInstance,
-        struct HINSTANCE__ *hPrevInstance,
-        char               *lpszCmdLine,
-        int                 nCmdShow)
-{
-	return main(__argc, __argv);
-}
-#endif
-
 /*
  * Editor modelines  -  https://www.wireshark.org/tools/modelines.html
  *
