@@ -178,18 +178,6 @@ capture_stop(capture_session *cap_session)
 }
 
 
-void
-capture_restart(capture_session *cap_session)
-{
-    capture_options *capture_opts = cap_session->capture_opts;
-
-    g_log(LOG_DOMAIN_CAPTURE, G_LOG_LEVEL_MESSAGE, "Capture Restart");
-
-    capture_opts->restart = TRUE;
-    capture_stop(cap_session);
-}
-
-
 void
 capture_kill_child(capture_session *cap_session)
 {
@@ -422,6 +410,7 @@ capture_input_new_file(capture_session *cap_session, gchar *new_file)
         /* (we can only have an open capture file in real_time_mode!) */
         if( ((capture_file *) cap_session->cf)->state != FILE_CLOSED) {
             if(capture_opts->real_time_mode) {
+                cap_session->session_will_restart = TRUE;
                 capture_callback_invoke(capture_cb_capture_update_finished, cap_session);
                 cf_finish_tail((capture_file *)cap_session->cf, &err);
                 cf_close((capture_file *)cap_session->cf);
@@ -527,9 +516,13 @@ capture_input_new_packets(capture_session *cap_session, int to_read)
 /* Capture child told us how many dropped packets it counted.
  */
 void
-capture_input_drops(capture_session *cap_session, guint32 dropped)
+capture_input_drops(capture_session *cap_session, guint32 dropped, char* interface_name)
 {
-    g_log(LOG_DOMAIN_CAPTURE, G_LOG_LEVEL_INFO, "%u packet%s dropped", dropped, plurality(dropped, "", "s"));
+    if (interface_name != NULL) {
+        g_log(LOG_DOMAIN_CAPTURE, G_LOG_LEVEL_INFO, "%u packet%s dropped from %s", dropped, plurality(dropped, "", "s"), interface_name);
+    } else {
+        g_log(LOG_DOMAIN_CAPTURE, G_LOG_LEVEL_INFO, "%u packet%s dropped", dropped, plurality(dropped, "", "s"));
+    }
 
     g_assert(cap_session->state == CAPTURE_RUNNING);
 
@@ -659,6 +652,7 @@ capture_input_closed(capture_session *cap_session, gchar *msg)
             /* Tell the GUI we are not doing a capture any more.
                Must be done after the cf_finish_tail(), so file lengths are
                correctly displayed */
+            cap_session->session_will_restart = FALSE;
             capture_callback_invoke(capture_cb_capture_update_finished, cap_session);
 
             /* Finish the capture. */
@@ -728,8 +722,6 @@ capture_input_closed(capture_session *cap_session, gchar *msg)
     if(capture_opts->restart) {
         capture_opts->restart = FALSE;
 
-        ws_unlink(capture_opts->save_file);
-
         /* If we have a ring buffer, the original save file has been overwritten
            with the "ring filename".  Restore it before starting again */
         if ((capture_opts->multi_files_on) && (capture_opts->orig_save_file != NULL)) {
@@ -737,21 +729,11 @@ capture_input_closed(capture_session *cap_session, gchar *msg)
             capture_opts->save_file = g_strdup(capture_opts->orig_save_file);
         }
 
-        /* if it was a tempfile, throw away the old filename (so it will become a tempfile again) */
-        if(cf_is_tempfile((capture_file *)cap_session->cf)) {
+        /* If it was a tempfile, throw away the old filename (so it will become a tempfile again) */
+        if (cf_is_tempfile((capture_file *)cap_session->cf)) {
             g_free(capture_opts->save_file);
             capture_opts->save_file = NULL;
         }
-
-        /* ... and start the capture again */
-        if (capture_opts->ifaces->len == 0) {
-            collect_ifaces(capture_opts);
-        }
-
-        /* close the currently loaded capture file */
-        cf_close((capture_file *)cap_session->cf);
-
-        capture_start(capture_opts, cap_session, cap_session->cap_data_info, NULL); /*XXX is this NULL ok or we need an update_cb???*/
     } else {
         /* We're not doing a capture any more, so we don't have a save file. */
         g_free(capture_opts->save_file);
@@ -765,11 +747,14 @@ capture_stat_start(capture_options *capture_opts)
     int stat_fd;
     ws_process_id fork_child;
     gchar *msg;
-    if_stat_cache_t *sc = NULL;
+    if_stat_cache_t *sc = g_new0(if_stat_cache_t, 1);
     if_stat_cache_item_t *sc_item;
     guint i;
     interface_t *device;
 
+    sc->stat_fd = -1;
+    sc->fork_child = WS_INVALID_PID;
+
     /* Fire up dumpcap. */
     /*
      * XXX - on systems with BPF, the number of BPF devices limits the
@@ -790,10 +775,8 @@ capture_stat_start(capture_options *capture_opts)
      * counts might not always be a good idea.
      */
     if (sync_interface_stats_open(&stat_fd, &fork_child, &msg, NULL) == 0) {
-        sc = (if_stat_cache_t *)g_malloc(sizeof(if_stat_cache_t));
         sc->stat_fd = stat_fd;
         sc->fork_child = fork_child;
-        sc->cache_list = NULL;
 
         /* Initialize the cache */
         for (i = 0; i < capture_opts->all_ifaces->len; i++) {
@@ -821,8 +804,9 @@ capture_stat_cache_update(if_stat_cache_t *sc)
     GList *sc_entry;
     if_stat_cache_item_t *sc_item;
 
-    if (!sc)
+    if (!sc || sc->fork_child == WS_INVALID_PID) {
         return;
+    }
 
     while (sync_pipe_gets_nonblock(sc->stat_fd, stat_line, MAX_STAT_LINE_LEN) > 0) {
         g_strstrip(stat_line);
@@ -849,7 +833,7 @@ capture_stats(if_stat_cache_t *sc, char *ifname, struct pcap_stat *ps)
     GList *sc_entry;
     if_stat_cache_item_t *sc_item;
 
-    if (!sc || !ifname || !ps) {
+    if (!sc || sc->fork_child == WS_INVALID_PID || !ifname || !ps) {
         return FALSE;
     }
 
@@ -872,13 +856,16 @@ capture_stat_stop(if_stat_cache_t *sc)
     int ret;
     gchar *msg;
 
-    if (!sc)
+    if (!sc) {
         return;
+    }
 
-    ret = sync_interface_stats_close(&sc->stat_fd, &sc->fork_child, &msg);
-    if (ret == -1) {
-        /* XXX - report failure? */
-        g_free(msg);
+    if (sc->fork_child != WS_INVALID_PID) {
+        ret = sync_interface_stats_close(&sc->stat_fd, &sc->fork_child, &msg);
+        if (ret == -1) {
+            /* XXX - report failure? */
+            g_free(msg);
+        }
     }
 
     for (sc_entry = sc->cache_list; sc_entry != NULL; sc_entry = g_list_next(sc_entry)) {
