@@ -54,6 +54,7 @@ private slots:
     void rowCountChanged();
     void invalidField(const QModelIndex &index, const QString& errMessage);
     void validField(const QModelIndex &index);
+    void treeItemClicked(const QModelIndex &index);
 
 private:
     Ui::ColoringRulesDialog *ui;
@@ -66,10 +67,12 @@ private:
 
     void checkUnknownColorfilters();
     void setColorButtons(QModelIndex &index);
-    void updateHint();
+    void updateHint(QModelIndex idx = QModelIndex());
 
     void addRule(bool copy_from_current = false);
     void changeColor(bool foreground = true);
+
+    bool isValidFilter(QString filter, QString *error);
 };
 
 #endif // COLORING_RULES_DIALOG_H
