@@ -28,9 +28,7 @@
 #include <QStack>
 #include <QUrl>
 
-#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
 #include <QWindow>
-#endif
 
 // To do:
 // - Fix "apply as filter" behavior.
@@ -50,6 +48,10 @@ ProtoTree::ProtoTree(QWidget *parent, epan_dissect_t *edt_fixed) :
     // similar to PacketListModel::data.
     setHeaderHidden(true);
 
+    // Shrink down to a small but nonzero size in the main splitter.
+    int one_em = fontMetrics().height();
+    setMinimumSize(one_em, one_em);
+
     setModel(proto_tree_model_);
 
     connect(this, SIGNAL(expanded(QModelIndex)), this, SLOT(syncExpanded(QModelIndex)));
@@ -138,7 +140,7 @@ void ProtoTree::contextMenuEvent(QContextMenuEvent *event)
     ctx_menu_.addMenu(submenu);
     submenu->addAction(window()->findChild<QAction *>("actionAnalyzeFollowTCPStream"));
     submenu->addAction(window()->findChild<QAction *>("actionAnalyzeFollowUDPStream"));
-    submenu->addAction(window()->findChild<QAction *>("actionAnalyzeFollowSSLStream"));
+    submenu->addAction(window()->findChild<QAction *>("actionAnalyzeFollowTLSStream"));
     submenu->addAction(window()->findChild<QAction *>("actionAnalyzeFollowHTTPStream"));
     ctx_menu_.addSeparator();
 
@@ -285,7 +287,7 @@ void ProtoTree::emitRelatedFrame(int related_frame, ft_framenum_type_t framenum_
 
 void ProtoTree::autoScrollTo(const QModelIndex &index)
 {
-    selectionModel()->select(index, QItemSelectionModel::ClearAndSelect);
+    selectionModel()->setCurrentIndex(index, QItemSelectionModel::ClearAndSelect);
     if (!index.isValid()) {
         return;
     }
@@ -587,13 +589,9 @@ bool ProtoTree::eventFilter(QObject * obj, QEvent * event)
 
                     DragLabel * content = new DragLabel(dfmd->labelText(), this);
 
-#if QT_VERSION >= QT_VERSION_CHECK(5, 1, 0)
                     qreal dpr = window()->windowHandle()->devicePixelRatio();
                     QPixmap pixmap(content->size() * dpr);
                     pixmap.setDevicePixelRatio(dpr);
-#else
-                    QPixmap pixmap(content->size());
-#endif
                     content->render(&pixmap);
                     drag->setPixmap(pixmap);
 
