@@ -21,6 +21,7 @@
 #include "epan/dissectors/packet-rtp.h"
 
 #include "ui/help_url.h"
+#include "ui/simple_dialog.h"
 #include <wsutil/utf8_entities.h>
 
 #include <wsutil/g711.h>
@@ -796,7 +797,7 @@ void RtpAnalysisDialog::savePayload(QTemporaryFile *tmpfile, tap_rtp_stat_t *sta
         (rtpinfo->info_payload_type == PT_CN_OLD)) {
     } else { /* All other payloads */
         const char *data;
-        size_t nchars;
+        qint64 nchars;
         tap_rtp_save_data_t save_data;
 
         if (!rtpinfo->info_all_data_present) {
@@ -827,7 +828,7 @@ void RtpAnalysisDialog::savePayload(QTemporaryFile *tmpfile, tap_rtp_stat_t *sta
         }
         if (save_data.payload_len > 0) {
             nchars = tmpfile->write(data, save_data.payload_len);
-            if (nchars != save_data.payload_len) {
+            if ((size_t)nchars != save_data.payload_len) {
                 /* Write error or short write */
                 err_str_ = tr("Can't save in a file: File I/O problem.");
                 save_payload_error_ = TAP_RTP_FILE_WRITE_ERROR;
@@ -893,13 +894,13 @@ void RtpAnalysisDialog::updateStatistics()
     }
 
     QString stats_tables = "<html><head><style>td{vertical-align:bottom;}</style></head><body>\n";
-    stats_tables += QString("<p>%1:%2 " UTF8_LEFT_RIGHT_ARROW)
+    stats_tables += "<h4>Forward</h4>\n";
+    stats_tables += QString("<p>%1:%2 " UTF8_RIGHTWARDS_ARROW)
             .arg(address_to_qstring(&fwd_statinfo_.id.src_addr, true))
             .arg(fwd_statinfo_.id.src_port);
     stats_tables += QString("<br>%1:%2</p>\n")
             .arg(address_to_qstring(&fwd_statinfo_.id.dst_addr, true))
             .arg(fwd_statinfo_.id.dst_port);
-    stats_tables += "<h4>Forward</h4>\n";
     stats_tables += "<p><table>\n";
     stats_tables += QString("<tr><th align=\"left\">SSRC</th><td>%1</td></tr>")
             .arg(int_to_qstring(fwd_statinfo_.id.ssrc, 8, 16));
@@ -932,6 +933,12 @@ void RtpAnalysisDialog::updateStatistics()
     stats_tables += "</table></p>\n";
 
     stats_tables += "<h4>Reverse</h4>\n";
+    stats_tables += QString("<p>%1:%2 " UTF8_RIGHTWARDS_ARROW)
+            .arg(address_to_qstring(&rev_statinfo_.id.src_addr, true))
+            .arg(rev_statinfo_.id.src_port);
+    stats_tables += QString("<br>%1:%2</p>\n")
+            .arg(address_to_qstring(&rev_statinfo_.id.dst_addr, true))
+            .arg(rev_statinfo_.id.dst_port);
     stats_tables += "<p><table>\n";
     stats_tables += QString("<tr><th align=\"left\">SSRC</th><td>%1</td></tr>")
             .arg(int_to_qstring(rev_statinfo_.id.ssrc, 8, 16));
@@ -1072,7 +1079,7 @@ size_t RtpAnalysisDialog::convert_payload_to_samples(unsigned int payload_type,
 
 gboolean RtpAnalysisDialog::saveAudioAUSilence(size_t total_len, QFile *save_file, gboolean *stop_flag)
 {
-    size_t nchars;
+    qint64 nchars;
     guint8 pd_out[2*4000];
     gint16 silence;
     guint8 pd[4];
@@ -1095,9 +1102,9 @@ gboolean RtpAnalysisDialog::saveAudioAUSilence(size_t total_len, QFile *save_fil
     return TRUE;
 }
 
-gboolean RtpAnalysisDialog::saveAudioAUUnidir(tap_rtp_stat_t &statinfo, QTemporaryFile *tempfile, QFile *save_file, size_t header_end, gboolean *stop_flag, gboolean interleave, size_t prefix_silence)
+gboolean RtpAnalysisDialog::saveAudioAUUnidir(tap_rtp_stat_t &statinfo, QTemporaryFile *tempfile, QFile *save_file, qint64 header_end, gboolean *stop_flag, gboolean interleave, size_t prefix_silence)
 {
-    size_t nchars;
+    qint64 nchars;
     guint8 pd_out[2*4000];
     guint8 pd[4];
     tap_rtp_save_data_t save_data;
@@ -1108,6 +1115,7 @@ gboolean RtpAnalysisDialog::saveAudioAUUnidir(tap_rtp_stat_t &statinfo, QTempora
         if (*stop_flag) {
             return FALSE;
         }
+
         ui->progressFrame->setValue(int(tempfile->pos() * 100 / tempfile->size()));
 
         sample_count=convert_payload_to_samples(save_data.payload_type, tempfile ,pd_out, save_data.payload_len);
@@ -1125,7 +1133,7 @@ gboolean RtpAnalysisDialog::saveAudioAUUnidir(tap_rtp_stat_t &statinfo, QTempora
                 }
                 nchars += save_file->write((const char *)pd, 2);
             }
-            if (nchars < sample_count*2) {
+            if ((size_t)nchars < sample_count*2) {
                 return FALSE;
             }
         }
@@ -1134,7 +1142,7 @@ gboolean RtpAnalysisDialog::saveAudioAUUnidir(tap_rtp_stat_t &statinfo, QTempora
     return TRUE;
 }
 
-gboolean RtpAnalysisDialog::saveAudioAUBidir(tap_rtp_stat_t &fwd_statinfo, tap_rtp_stat_t &rev_statinfo, QTemporaryFile *fwd_tempfile, QTemporaryFile *rev_tempfile, QFile *save_file, size_t header_end, gboolean *stop_flag, size_t prefix_silence_fwd, size_t prefix_silence_rev)
+gboolean RtpAnalysisDialog::saveAudioAUBidir(tap_rtp_stat_t &fwd_statinfo, tap_rtp_stat_t &rev_statinfo, QTemporaryFile *fwd_tempfile, QTemporaryFile *rev_tempfile, QFile *save_file, qint64 header_end, gboolean *stop_flag, size_t prefix_silence_fwd, size_t prefix_silence_rev)
 {
     if (! saveAudioAUUnidir(fwd_statinfo, fwd_tempfile, save_file, header_end, stop_flag, TRUE, prefix_silence_fwd))
     {
@@ -1151,8 +1159,8 @@ gboolean RtpAnalysisDialog::saveAudioAUBidir(tap_rtp_stat_t &fwd_statinfo, tap_r
 gboolean RtpAnalysisDialog::saveAudioAU(StreamDirection direction, QFile *save_file, gboolean *stop_flag, RtpAnalysisDialog::SyncType sync)
 {
     guint8 pd[4];
-    size_t nchars;
-    size_t header_end;
+    qint64 nchars;
+    qint64 header_end;
     size_t fwd_total_len;
     size_t rev_total_len;
     size_t total_len;
@@ -1410,14 +1418,41 @@ void RtpAnalysisDialog::saveAudio(RtpAnalysisDialog::StreamDirection direction,
     ui->progressFrame->showProgress(true, true, &stop_flag);
 
     if (save_format == save_audio_au_) { /* au format */
+        bool showPayloadWarning = TRUE;
+
         if ((fwd_statinfo_.rtp_stats.clock_rate != 8000) ||
             ((rev_statinfo_.rtp_stats.clock_rate != 0) && (rev_statinfo_.rtp_stats.clock_rate != 8000))
            ) {
             QMessageBox::warning(this, tr("Warning"), tr("Can save audio with 8000 Hz clock rate only"));
-        } else {
-            if (! saveAudioAU(direction, &save_file, &stop_flag, sync)) {
+            goto copy_file_err;
+        }
+
+        /* Check for supported codecs */
+        if (rtpstream_is_payload_used(&fwd_statinfo_, PT_PCMU)) { showPayloadWarning=FALSE; }
+        if (rtpstream_is_payload_used(&fwd_statinfo_, PT_PCMA)) { showPayloadWarning=FALSE; }
+        /* ED-137 silence */
+        if (rtpstream_is_payload_used(&fwd_statinfo_, PT_UNDF_123)) { showPayloadWarning=FALSE; }
+        if (rev_statinfo_.rtp_stats.clock_rate != 0)
+        { /* Reverse stream is defined */
+            bool showRevPayloadWarning = TRUE;
+
+            /* Check for supported codecs */
+            if (rtpstream_is_payload_used(&rev_statinfo_, PT_PCMU)) { showRevPayloadWarning=FALSE; }
+            if (rtpstream_is_payload_used(&rev_statinfo_, PT_PCMA)) { showRevPayloadWarning=FALSE; }
+          /* ED-137 silence */
+            if (rtpstream_is_payload_used(&rev_statinfo_, PT_UNDF_123)) { showRevPayloadWarning=FALSE; }
+            if (showRevPayloadWarning) { showPayloadWarning=TRUE; }
+        }
+
+        /* If unsupported coded is used, warn user */
+        if (showPayloadWarning)
+        {
+            QMessageBox::warning(this, tr("Error"), tr("Can save audio with PCM u-law or A-law encoding only"));
+            goto copy_file_err;
+        }
+
+        if (! saveAudioAU(direction, &save_file, &stop_flag, sync)) {
                 goto copy_file_err;
-            }
         }
     } else if (save_format == save_audio_raw_) { /* raw format */
         if (! saveAudioRAW(direction, &save_file, &stop_flag)) {
