@@ -322,7 +322,13 @@ void SequenceDiagram::draw(QCPPainter *painter)
                     ? arrow_start.x() : arrow_end.x();
             double arrow_width = (arrow_end.x() - arrow_start.x()) * dir_mul;
             QString arrow_label = cfm.elidedText(sai->frame_label, Qt::ElideRight, arrow_width);
-            QPoint text_pt(comment_start + ((arrow_width - cfm.width(arrow_label)) / 2),
+            int arrow_label_width = 0;
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 11, 0))
+            arrow_label_width = cfm.horizontalAdvance(arrow_label);
+#else
+            arrow_label_width = cfm.width(arrow_label);
+#endif
+            QPoint text_pt(comment_start + ((arrow_width - arrow_label_width) / 2),
                           arrow_start.y() - (en_w / 2));
 
             painter->setFont(comment_axis_->tickLabelFont());
@@ -333,9 +339,13 @@ void SequenceDiagram::draw(QCPPainter *painter)
                 int right_x = dir_mul > 0 ? arrow_end.x() : arrow_start.x();
                 QString port_left = QString::number(dir_mul > 0 ? sai->port_src : sai->port_dst);
                 QString port_right = QString::number(dir_mul > 0 ? sai->port_dst : sai->port_src);
-
-                text_pt = QPoint(left_x - en_w - cfm.width(port_left),
-                                arrow_start.y() + (en_w / 2));
+                int port_left_width = 0;
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 11, 0))
+                port_left_width = cfm.horizontalAdvance(port_left);
+#else
+                port_left_width = cfm.width(port_left);
+#endif
+                text_pt = QPoint(left_x - en_w - port_left_width, arrow_start.y() + (en_w / 2));
                 painter->drawText(text_pt, port_left);
 
                 text_pt.setX(right_x + en_w);
