@@ -44,15 +44,14 @@ free_first(gpointer data, gpointer user_data _U_)
 }
 
 static void
-tsn_free(gpointer data, gpointer user_data _U_)
+tsn_free(gpointer data)
 {
     tsn_t *tsn;
 
     tsn = (tsn_t *) data;
     if (tsn->tsns != NULL)
     {
-        g_list_foreach(tsn->tsns, free_first, NULL);
-        g_list_free(tsn->tsns);
+        g_list_free_full(tsn->tsns, g_free);
     }
     free_address(&tsn->src);
     free_address(&tsn->dst);
@@ -60,7 +59,16 @@ tsn_free(gpointer data, gpointer user_data _U_)
 }
 
 static void
-store_free(gpointer data, gpointer user_data _U_)
+chunk_free(gpointer data)
+{
+    sctp_addr_chunk *chunk = (sctp_addr_chunk *) data;
+
+    free_address(&chunk->addr);
+    g_free(chunk);
+}
+
+static void
+store_free(gpointer data)
 {
     address *addr = (address *) data;
 
@@ -82,22 +90,19 @@ reset(void *arg)
 
         if (info->addr1 != NULL)
         {
-            g_list_foreach(info->addr1, store_free, NULL);
-            g_list_free(info->addr1);
+            g_list_free_full(info->addr1, store_free);
             info->addr1 = NULL;
         }
 
         if (info->addr2 != NULL)
         {
-            g_list_foreach(info->addr2, store_free, NULL);
-            g_list_free(info->addr2);
+            g_list_free_full(info->addr2, store_free);
             info->addr2 = NULL;
         }
 
         if (info->error_info_list != NULL)
         {
-            g_list_foreach(info->error_info_list, free_first, NULL);
-            g_list_free(info->error_info_list);
+            g_list_free_full(info->error_info_list, g_free);
             info->error_info_list = NULL;
         }
 
@@ -109,29 +114,25 @@ reset(void *arg)
 
         if (info->tsn1 != NULL)
         {
-            g_list_foreach(info->tsn1, tsn_free, NULL);
-            g_list_free(info->tsn1);
+            g_list_free_full(info->tsn1, tsn_free);
             info->tsn1 = NULL;
         }
 
         if (info->tsn2 != NULL)
         {
-            g_list_foreach(info->tsn2, tsn_free, NULL);
-            g_list_free(info->tsn2);
+            g_list_free_full(info->tsn2, tsn_free);
             info->tsn2 = NULL;
         }
 
         if (info->sack1 != NULL)
         {
-            g_list_foreach(info->sack1, tsn_free, NULL);
-            g_list_free(info->sack1);
+            g_list_free_full(info->sack1, tsn_free);
             info->sack1 = NULL;
         }
 
         if (info->sack2 != NULL)
         {
-            g_list_foreach(info->sack2, tsn_free, NULL);
-            g_list_free(info->sack2);
+            g_list_free_full(info->sack2, tsn_free);
             info->sack2 = NULL;
         }
 
@@ -152,6 +153,13 @@ reset(void *arg)
             g_slist_foreach(info->min_max, free_first, NULL);
             info->min_max = NULL;
         }
+
+        if (info->addr_chunk_count) {
+            g_list_free_full(info->addr_chunk_count, chunk_free);
+        }
+
+        g_free(info->dir1);
+        g_free(info->dir2);
         free_address(&info->src);
         free_address(&info->dst);
 
@@ -312,7 +320,7 @@ add_address(address *vadd, sctp_assoc_info_t *info, guint16 direction)
     return info;
 }
 
-static gboolean
+static tap_packet_status
 packet(void *tapdata _U_, packet_info *pinfo, epan_dissect_t *edt _U_, const void *data)
 {
     const struct _sctp_info *sctp_info = (const struct _sctp_info *)data;
@@ -396,6 +404,7 @@ packet(void *tapdata _U_, packet_info *pinfo, epan_dissect_t *edt _U_, const voi
             info->init              = FALSE;
             info->initack           = FALSE;
             info->check_address     = FALSE;
+            info->firstdata         = TRUE;
             info->direction         = sctp_info->direction;
             info                    = calc_checksum(sctp_info, info);
             info->n_packets         = 1;
@@ -428,6 +437,12 @@ packet(void *tapdata _U_, packet_info *pinfo, epan_dissect_t *edt _U_, const voi
             info->sort_tsn2         = g_ptr_array_new_with_free_func(g_free);
             info->sort_sack1        = g_ptr_array_new_with_free_func(g_free);
             info->sort_sack2        = g_ptr_array_new_with_free_func(g_free);
+            info->dir1              = g_new0(sctp_init_collision_t, 1);
+            info->dir1->init_min_tsn = 0xffffffff;
+            info->dir1->initack_min_tsn = 0xffffffff;
+            info->dir2              = g_new0(sctp_init_collision_t, 1);
+            info->dir2->init_min_tsn = 0xffffffff;
+            info->dir2->initack_min_tsn = 0xffffffff;
 
             for (i=0; i < NUM_CHUNKS; i++)
             {
@@ -521,6 +536,27 @@ packet(void *tapdata _U_, packet_info *pinfo, epan_dissect_t *edt _U_, const voi
                 info->chunk_count[idx]++;
                 info->ep1_chunk_count[idx]++;
                 info = add_chunk_count(&tmp_info.src, info, 1, idx);
+                if (info->direction == 1) {
+                    if (tvb_get_guint8(sctp_info->tvb[0],0) == SCTP_INIT_CHUNK_ID) {
+                        info->dir1->init = TRUE;
+                        info->dir1->init_min_tsn = info->min_tsn1;
+                        info->dir1->init_vtag = info->verification_tag2;
+                    } else if (tvb_get_guint8(sctp_info->tvb[0],0) == SCTP_INIT_ACK_CHUNK_ID) {
+                        info->dir1->initack = TRUE;
+                        info->dir1->initack_min_tsn = info->min_tsn1;
+                        info->dir1->initack_vtag = info->verification_tag2;
+                    }
+                } else {
+                    if (tvb_get_guint8(sctp_info->tvb[0],0) == SCTP_INIT_CHUNK_ID) {
+                        info->dir2->init = TRUE;
+                        info->dir2->init_min_tsn = info->min_tsn1;
+                        info->dir2->init_vtag = info->verification_tag2;
+                    } else if (tvb_get_guint8(sctp_info->tvb[0],0) == SCTP_INIT_ACK_CHUNK_ID) {
+                        info->dir2->initack = TRUE;
+                        info->dir2->initack_min_tsn = info->min_tsn1;
+                        info->dir2->initack_vtag = info->verification_tag2;
+                    }
+                }
             }
             else
             {
@@ -566,8 +602,8 @@ packet(void *tapdata _U_, packet_info *pinfo, epan_dissect_t *edt _U_, const voi
                     }
                     if (datachunk || forwardchunk)
                     {
-
                         tsnumber = tvb_get_ntohl((sctp_info->tvb)[chunk_number], DATA_CHUNK_TSN_OFFSET);
+                        info->firstdata = FALSE;
                         if (tsnumber < info->min_tsn1)
                             info->min_tsn1 = tsnumber;
                         if (tsnumber > info->max_tsn1)
@@ -810,7 +846,6 @@ packet(void *tapdata _U_, packet_info *pinfo, epan_dissect_t *edt _U_, const voi
                 ((tvb_get_guint8(sctp_info->tvb[0],0)) == SCTP_INIT_CHUNK_ID))
         {
             tsnumber = tvb_get_ntohl((sctp_info->tvb)[chunk_number], INIT_CHUNK_INITIAL_TSN_OFFSET);
-
             if (info->direction == 2)
             {
                 if (tsnumber < info->min_tsn2)
@@ -861,6 +896,37 @@ packet(void *tapdata _U_, packet_info *pinfo, epan_dissect_t *edt _U_, const voi
                     info = add_address(store, info, info->direction);
                 }
             }
+            if (info->direction == 1) {
+                if (info->dir1->init || info->dir1->initack) {
+                    info->init_collision = TRUE;
+                }
+                if (tvb_get_guint8(sctp_info->tvb[0],0) == SCTP_INIT_CHUNK_ID) {
+                    info->dir1->init = TRUE;
+                    info->dir1->init_min_tsn = tvb_get_ntohl((sctp_info->tvb)[0], INIT_CHUNK_INITIAL_TSN_OFFSET);
+                    info->min_tsn1 = info->dir1->init_min_tsn;
+                    info->dir1->init_vtag = tvb_get_ntohl(sctp_info->tvb[0], INIT_CHUNK_INITIATE_TAG_OFFSET);
+                } else if (tvb_get_guint8(sctp_info->tvb[0],0) == SCTP_INIT_ACK_CHUNK_ID) {
+                    info->dir1->initack = TRUE;
+                    info->dir1->initack_min_tsn = tvb_get_ntohl((sctp_info->tvb)[0], INIT_CHUNK_INITIAL_TSN_OFFSET);
+                    info->min_tsn1 = info->dir1->initack_min_tsn;
+                    info->dir1->initack_vtag = tvb_get_ntohl(sctp_info->tvb[0], INIT_CHUNK_INITIATE_TAG_OFFSET);
+                }
+            } else {
+                if (info->dir2->init || info->dir2->initack) {
+                    info->init_collision = TRUE;
+                }
+                if (tvb_get_guint8(sctp_info->tvb[0],0) == SCTP_INIT_CHUNK_ID) {
+                    info->dir2->init = TRUE;
+                    info->dir2->init_min_tsn = tvb_get_ntohl((sctp_info->tvb)[0], INIT_CHUNK_INITIAL_TSN_OFFSET);
+                    info->min_tsn2 = info->dir2->init_min_tsn;
+                    info->dir2->init_vtag = tvb_get_ntohl(sctp_info->tvb[0], INIT_CHUNK_INITIATE_TAG_OFFSET);
+                } else if (tvb_get_guint8(sctp_info->tvb[0],0) == SCTP_INIT_ACK_CHUNK_ID) {
+                    info->dir2->initack = TRUE;
+                    info->dir2->initack_min_tsn = tvb_get_ntohl((sctp_info->tvb)[0], INIT_CHUNK_INITIAL_TSN_OFFSET);
+                    info->min_tsn2 = info->dir2->initack_min_tsn;
+                    info->dir2->initack_vtag = tvb_get_ntohl(sctp_info->tvb[0], INIT_CHUNK_INITIATE_TAG_OFFSET);
+                }
+            }
             if ((tvb_get_guint8(sctp_info->tvb[0],0)) == SCTP_INIT_ACK_CHUNK_ID)
             {
                 info->initack = TRUE;
@@ -933,7 +999,7 @@ packet(void *tapdata _U_, packet_info *pinfo, epan_dissect_t *edt _U_, const voi
                     }
                     tsn->tsns = g_list_append(tsn->tsns, t_s_n);
 
-                    tsn_s = g_new(struct tsn_sort, 1);
+                    tsn_s = g_new0(struct tsn_sort, 1);
                     tsn_s->tsnumber = tsnumber;
                     tsn_s->secs  = tsn->secs = (guint32)pinfo->rel_ts.secs;
                     tsn_s->usecs = tsn->usecs = (guint32)pinfo->rel_ts.nsecs/1000;
@@ -959,9 +1025,20 @@ packet(void *tapdata _U_, packet_info *pinfo, epan_dissect_t *edt _U_, const voi
 
                     if (info->direction == 1)
                     {
-                        if(tsnumber < info->min_tsn1)
-                            info->min_tsn1 = tsnumber;
-                        if ((info->init == TRUE || (info->initack == TRUE && info->initack_dir == 1))&& tsnumber >= info->min_tsn1 && tsnumber <= info->max_tsn1)
+                        if (info->firstdata) {
+                            info->firstdata = FALSE;
+                            if (info->init_collision) {
+                                if (tsnumber != info->min_tsn1) {
+                                    info->min_tsn1 = info->dir1->init_min_tsn;
+                                }
+                                info->min_tsn2 = info->dir2->initack_min_tsn;
+                            }
+                        } else {
+                            if(tsnumber < info->min_tsn1) {
+                                info->min_tsn1 = tsnumber;
+                            }
+                        }
+                        if ((info->init || (info->initack && info->initack_dir == 1))&& tsnumber >= info->min_tsn1 && tsnumber <= info->max_tsn1)
                         {
                             if (datachunk)
                             {
@@ -999,11 +1076,21 @@ packet(void *tapdata _U_, packet_info *pinfo, epan_dissect_t *edt _U_, const voi
                     }
                     else if (info->direction == 2)
                     {
+                        if (info->firstdata) {
+                            info->firstdata = FALSE;
+                            if (info->init_collision) {
+                                if (tsnumber != info->min_tsn2) {
+                                    info->min_tsn2 = info->dir2->init_min_tsn;
+                                    info->initack_dir = 2;
+                                }
+                                info->min_tsn1 = info->dir1->initack_min_tsn;
+                            }
+                        } else {
+                            if(tsnumber < info->min_tsn2)
+                                info->min_tsn2 = tsnumber;
+                        }
 
-                        if(tsnumber < info->min_tsn2)
-                            info->min_tsn2 = tsnumber;
-
-                        if ((info->initack == TRUE && info->initack_dir == 2)&& tsnumber >= info->min_tsn2 && tsnumber <= info->max_tsn2)
+                        if ((info->initack && info->initack_dir == 2)&& tsnumber >= info->min_tsn2 && tsnumber <= info->max_tsn2)
                         {
                             if (datachunk)
                             {
@@ -1064,7 +1151,7 @@ packet(void *tapdata _U_, packet_info *pinfo, epan_dissect_t *edt _U_, const voi
                     tvb_memcpy(sctp_info->tvb[chunk_number], (guint8 *)(t_s_n),0, length);
                     sack->tsns = g_list_append(sack->tsns, t_s_n);
                     sackchunk = TRUE;
-                    tsn_s = g_new(struct tsn_sort, 1);
+                    tsn_s = g_new0(struct tsn_sort, 1);
                     tsn_s->tsnumber = tsnumber;
                     tsn_s->secs   = tsn->secs = (guint32)pinfo->rel_ts.secs;
                     tsn_s->usecs  = tsn->usecs = (guint32)pinfo->rel_ts.nsecs/1000;
@@ -1102,7 +1189,6 @@ packet(void *tapdata _U_, packet_info *pinfo, epan_dissect_t *edt _U_, const voi
                     }
                     else if (info->direction == 1)
                     {
-
                         if(tsnumber < info->min_tsn2)
                             info->min_tsn2 = tsnumber;
                         if(tsnumber > info->max_tsn2)
@@ -1138,12 +1224,12 @@ packet(void *tapdata _U_, packet_info *pinfo, epan_dissect_t *edt _U_, const voi
         info->n_packets++;
     }
     if (tsn && !tsn_used)
-        tsn_free(tsn, NULL);
+        tsn_free(tsn);
     if (sack && !sack_used)
-        tsn_free(sack, NULL);
+        tsn_free(sack);
     free_address(&tmp_info.src);
     free_address(&tmp_info.dst);
-    return TRUE;
+    return TAP_PACKET_REDRAW;
 }
 
 
@@ -1186,7 +1272,7 @@ register_tap_listener_sctp_stat(void)
 
     if (!sctp_tapinfo_struct.is_registered)
     {
-        if ((error_string = register_tap_listener("sctp", &sctp_tapinfo_struct, NULL, 0, reset, packet, NULL))) {
+        if ((error_string = register_tap_listener("sctp", &sctp_tapinfo_struct, NULL, 0, reset, packet, NULL, NULL))) {
             simple_dialog(ESD_TYPE_ERROR, ESD_BTN_OK, "%s", error_string->str);
             g_string_free(error_string, TRUE);
             return;
