@@ -284,6 +284,9 @@ extern "C" {
 #define WTAP_ENCAP_RUBY_MARSHAL                 201
 #define WTAP_ENCAP_RFC7468                      202
 #define WTAP_ENCAP_SYSTEMD_JOURNAL              203 /* Event, not a packet */
+#define WTAP_ENCAP_EBHSCR                       204
+#define WTAP_ENCAP_VPP                          205
+#define WTAP_ENCAP_IEEE802_15_4_TAP             206
 
 /* After adding new item here, please also add new item to encap_table_base array */
 
@@ -394,19 +397,30 @@ extern "C" {
 /* if you add to the above, update wtap_tsprec_string() */
 
 /*
- * We support one maximum packet size for most link-layer header types
- * and another for D-Bus, because the maximum packet size for D-Bus
- * is 128MB, as per
+ * Maximum packet sizes.
+ *
+ * For most link-layer types, we use 262144, which is currently
+ * libpcap's MAXIMUM_SNAPLEN.
+ *
+ * For WTAP_ENCAP_DBUS, the maximum is 128MiB, as per
  *
  *    https://dbus.freedesktop.org/doc/dbus-specification.html#message-protocol-messages
  *
- * and that's a lot bigger than the 256KB that we use elsewhere.
+ * For WTAP_ENCAP_EBHSCR, the maximum is 8MiB, as per
  *
- * We don't want to write out files that specify a maximum packet size of
- * 128MB if we don't have to, as software reading those files might
- * allocate a buffer much larger than necessary, wasting memory.
+ *    https://www.elektrobit.com/ebhscr
+ *
+ * For WTAP_ENCAP_USBPCAP, the maximum is 128MiB, as per
+ *
+ *    https://bugs.wireshark.org/bugzilla/show_bug.cgi?id=15985
+ *
+ * We don't want to write out files that specify a maximum packet size
+ * greater than 262144 if we don't have to, as software reading those
+ * files might allocate a buffer much larger than necessary, wasting memory.
  */
 #define WTAP_MAX_PACKET_SIZE_STANDARD    262144
+#define WTAP_MAX_PACKET_SIZE_USBPCAP     (128*1024*1024)
+#define WTAP_MAX_PACKET_SIZE_EBHSCR      (8*1024*1024)
 #define WTAP_MAX_PACKET_SIZE_DBUS        (128*1024*1024)
 
 /*
@@ -603,6 +617,8 @@ struct p2p_phdr {
 #define PHDR_802_11_PHY_11N            7 /* 802.11n */
 #define PHDR_802_11_PHY_11AC           8 /* 802.11ac */
 #define PHDR_802_11_PHY_11AD           9 /* 802.11ad */
+#define PHDR_802_11_PHY_11AH          10 /* 802.11ah */
+#define PHDR_802_11_PHY_11AX          11 /* 802.11ax */
 
 /*
  * PHY-specific information.
@@ -1265,11 +1281,82 @@ typedef struct {
                                 /* options */
     guint64   drop_count;       /* number of packets lost (by the interface and the
                                    operating system) between this packet and the preceding one. */
-    guint32   pack_flags;       /* XXX - 0 for now (any value for "we don't have it"?) */
+    guint32   pack_flags;       /* various flags, as per pcapng EPB */
 
     union wtap_pseudo_header  pseudo_header;
 } wtap_packet_header;
 
+/*
+ * The pcapng specification says "The word is encoded as an unsigned
+ * 32-bit integer, using the endianness of the Section Header Block
+ * scope it is in. In the following table, the bits are numbered with
+ * 0 being the most-significant bit and 31 being the least-significant
+ * bit of the 32-bit unsigned integer."
+ *
+ * From that, the direction, in bits 0 and 1, is at the *top* of the word.
+ *
+ * However, several implementations, such as:
+ *
+ *   the Wireshark pcapng file reading code;
+ *
+ *   macOS libpcap and tcpdump;
+ *
+ *   text2pcap;
+ *
+ *   and probably the software that generated the capture in bug 11665;
+ *
+ * treat 0 as the *least*-significant bit and bit 31 being the *most*-
+ * significant bit of the flags word, and put the direction at the
+ * *bottom* of the word.
+ *
+ * For now, we go with the known implementations.
+ */
+
+/* Direction field of the packet flags */
+#define PACK_FLAGS_DIRECTION_MASK     0x00000003 /* unshifted */
+#define PACK_FLAGS_DIRECTION_SHIFT    0
+#define PACK_FLAGS_DIRECTION(pack_flags) (((pack_flags) & PACK_FLAGS_DIRECTION_MASK) >> PACK_FLAGS_DIRECTION_SHIFT)
+#define PACK_FLAGS_DIRECTION_UNKNOWN  0
+#define PACK_FLAGS_DIRECTION_INBOUND  1
+#define PACK_FLAGS_DIRECTION_OUTBOUND 2
+
+/* Reception type field of the packet flags */
+#define PACK_FLAGS_RECEPTION_TYPE_MASK        0x0000001C /* unshifted */
+#define PACK_FLAGS_RECEPTION_TYPE_SHIFT       2
+#define PACK_FLAGS_RECEPTION_TYPE(pack_flags) (((pack_flags) & PACK_FLAGS_RECEPTION_TYPE_MASK) >> PACK_FLAGS_RECEPTION_TYPE_SHIFT)
+#define PACK_FLAGS_RECEPTION_TYPE_UNSPECIFIED 0
+#define PACK_FLAGS_RECEPTION_TYPE_UNICAST     1
+#define PACK_FLAGS_RECEPTION_TYPE_MULTICAST   2
+#define PACK_FLAGS_RECEPTION_TYPE_BROADCAST   3
+#define PACK_FLAGS_RECEPTION_TYPE_PROMISCUOUS 4
+
+/* FCS length field of the packet flags */
+#define PACK_FLAGS_FCS_LENGTH_MASK                        0x000001E0 /* unshifted */
+#define PACK_FLAGS_FCS_LENGTH_SHIFT                       5
+#define PACK_FLAGS_FCS_LENGTH(pack_flags) (((pack_flags) & PACK_FLAGS_FCS_LENGTH_MASK) >> PACK_FLAGS_FCS_LENGTH_SHIFT)
+
+/* Reserved bits of the packet flags */
+#define PACK_FLAGS_RESERVED_MASK                          0x0000FE00
+
+/* Link-layer-dependent errors of the packet flags */
+
+/* For Ethernet and possibly some other network types */
+#define PACK_FLAGS_CRC_ERROR                   0x01000000
+#define PACK_FLAGS_PACKET_TOO_LONG             0x02000000
+#define PACK_FLAGS_PACKET_TOO_SHORT            0x04000000
+#define PACK_FLAGS_WRONG_INTER_FRAME_GAP       0x08000000
+#define PACK_FLAGS_UNALIGNED_FRAME             0x10000000
+#define PACK_FLAGS_START_FRAME_DELIMITER_ERROR 0x20000000
+#define PACK_FLAGS_PREAMBLE_ERROR              0x40000000
+#define PACK_FLAGS_SYMBOL_ERROR                0x80000000
+
+/* Construct a pack_flags value from its subfield values */
+#define PACK_FLAGS_VALUE(direction, reception_type, fcs_length, ll_dependent_errors) \
+    (((direction) << 30) | \
+    ((reception_type) << 27) | \
+    ((fcs_length) << 23) | \
+    (ll_dependent_errors))
+
 typedef struct {
     guint     record_type;      /* the type of record this is - file type-specific value */
     guint32   record_len;       /* length of the record */
@@ -1923,6 +2010,16 @@ gboolean wtap_dump_supports_comment_types(int filetype, guint32 comment_types);
 WS_DLL_PUBLIC
 void wtap_dump_params_init(wtap_dump_params *params, wtap *wth);
 
+/**
+ * Remove any decryption secret information from the per-file information;
+ * used if we're stripping decryption secrets as we write the file.
+ *
+ * @param params The parameters for wtap_dump_* from which to remove the
+ * decryption secrets..
+ */
+WS_DLL_PUBLIC
+void wtap_dump_params_discard_decryption_secrets(wtap_dump_params *params);
+
 /**
  * Free memory associated with the wtap_dump_params when it is no longer in
  * use by wtap_dumper.
@@ -2009,6 +2106,8 @@ WS_DLL_PUBLIC
 gboolean wtap_dump_set_addrinfo_list(wtap_dumper *wdh, addrinfo_lists_t *addrinfo_lists);
 WS_DLL_PUBLIC
 gboolean wtap_dump_get_needs_reload(wtap_dumper *wdh);
+WS_DLL_PUBLIC
+void wtap_dump_discard_decryption_secrets(wtap_dumper *wdh);
 
 /**
  * Closes open file handles and frees memory associated with wdh. Note that
@@ -2054,11 +2153,11 @@ WS_DLL_PUBLIC
 void wtap_free_extensions_list(GSList *extensions);
 
 WS_DLL_PUBLIC
-const char *wtap_encap_string(int encap);
+const char *wtap_encap_name(int encap);
 WS_DLL_PUBLIC
-const char *wtap_encap_short_string(int encap);
+const char *wtap_encap_description(int encap);
 WS_DLL_PUBLIC
-int wtap_short_string_to_encap(const char *short_name);
+int wtap_name_to_encap(const char *short_name);
 
 WS_DLL_PUBLIC
 const char* wtap_tsprec_string(int tsprec);
@@ -2108,7 +2207,7 @@ WS_DLL_PUBLIC
 void wtap_deregister_file_type_subtype(const int file_type_subtype);
 
 WS_DLL_PUBLIC
-int wtap_register_encap_type(const char* name, const char* short_name);
+int wtap_register_encap_type(const char *description, const char *name);
 
 /*** Cleanup the interal library structures */
 WS_DLL_PUBLIC
