@@ -2109,6 +2109,71 @@ files_identical(const char *fname1, const char *fname2)
 #endif
 }
 
+gboolean
+file_needs_reopen(int fd, const char* filename)
+{
+#ifdef _WIN32
+    /* Windows handles st_dev in a way unsuitable here:
+     *   * _fstat() simply casts the file descriptor (ws_fileno(fp)) to unsigned
+     *     and assigns this value to st_dev and st_rdev
+     *   * _wstat() converts drive letter (eg. C) to number (A=0, B=1, C=2, ...)
+     *     and assigns such number to st_dev and st_rdev
+     *
+     * The st_ino parameter is simply zero as there is no specific assignment
+     * to it in the Universal CRT source code.
+     *
+     * Thus instead of using fstat(), use Windows specific API.
+     */
+
+    HANDLE open_handle = (HANDLE)_get_osfhandle(fd);
+    HANDLE current_handle = CreateFile(utf_8to16(filename), FILE_READ_ATTRIBUTES,
+                            FILE_SHARE_DELETE | FILE_SHARE_READ | FILE_SHARE_WRITE,
+                            NULL, OPEN_EXISTING, 0, NULL);
+    BY_HANDLE_FILE_INFORMATION open_info, current_info;
+
+    if (current_handle == INVALID_HANDLE_VALUE) {
+        return TRUE;
+    }
+
+#if (_WIN32_WINNT >= _WIN32_WINNT_WIN8)
+    FILE_ID_INFO open_id, current_id;
+    if (GetFileInformationByHandleEx(open_handle, FileIdInfo, &open_id, sizeof(open_id)) &&
+        GetFileInformationByHandleEx(current_handle, FileIdInfo, &current_id, sizeof(current_id))) {
+        /* 128-bit identifier is available, use it */
+        CloseHandle(current_handle);
+        return open_id.VolumeSerialNumber != current_id.VolumeSerialNumber ||
+               memcmp(&open_id.FileId, &current_id.FileId, sizeof(open_id.FileId)) != 0;
+    }
+#endif /* _WIN32_WINNT >= _WIN32_WINNT_WIN8 */
+    if (GetFileInformationByHandle(open_handle, &open_info) &&
+        GetFileInformationByHandle(current_handle, &current_info)) {
+        /* Fallback to 64-bit identifier */
+        CloseHandle(current_handle);
+        guint64 open_size = (((guint64)open_info.nFileSizeHigh) << 32) | open_info.nFileSizeLow;
+        guint64 current_size = (((guint64)current_info.nFileSizeHigh) << 32) | current_info.nFileSizeLow;
+        return open_info.dwVolumeSerialNumber != current_info.dwVolumeSerialNumber ||
+               open_info.nFileIndexHigh != current_info.nFileIndexHigh ||
+               open_info.nFileIndexLow != current_info.nFileIndexLow ||
+               open_size > current_size;
+    }
+    CloseHandle(current_handle);
+    return TRUE;
+#else
+    ws_statb64 open_stat, current_stat;
+
+    /* consider a file deleted when stat fails for either file,
+     * or when the residing device / inode has changed. */
+    if (0 != ws_fstat64(fd, &open_stat))
+        return TRUE;
+    if (0 != ws_stat64(filename, &current_stat))
+        return TRUE;
+
+    return open_stat.st_dev != current_stat.st_dev ||
+           open_stat.st_ino != current_stat.st_ino ||
+           open_stat.st_size > current_stat.st_size;
+#endif
+}
+
 /*
  * Copy a file in binary mode, for those operating systems that care about
  * such things.  This should be OK for all files, even text files, as
@@ -2190,8 +2255,6 @@ data_file_url(const gchar *filename)
     /* Absolute path? */
     if(g_path_is_absolute(filename)) {
         file_path = g_strdup(filename);
-    } else if(running_in_build_directory()) {
-        file_path = g_strdup_printf("%s/doc/%s", get_datafile_dir(), filename);
     } else {
         file_path = g_strdup_printf("%s/%s", get_datafile_dir(), filename);
     }
